// Copyright 2015, VIXL authors
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//   * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//   * Neither the name of ARM Limited nor the names of its contributors may be
//     used to endorse or promote products derived from this software without
//     specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


// ---------------------------------------------------------------------
// This file is auto generated using tools/generate_simulator_traces.py.
//
// PLEASE DO NOT EDIT.
// ---------------------------------------------------------------------

#ifndef VIXL_ASSEMBLER_COND_RD_OPERAND_RN_SHIFT_AMOUNT_1TO32_IN_IT_BLOCK_MOV_T32_H_
#define VIXL_ASSEMBLER_COND_RD_OPERAND_RN_SHIFT_AMOUNT_1TO32_IN_IT_BLOCK_MOV_T32_H_

const byte kInstruction_mov_ge_r7_r6_LSR_20[] = {
  0xa8, 0xbf, 0x37, 0x0d // It ge; mov ge r7 r6 LSR 20
};
const byte kInstruction_mov_gt_r4_r6_LSR_32[] = {
  0xc8, 0xbf, 0x34, 0x08 // It gt; mov gt r4 r6 LSR 32
};
const byte kInstruction_mov_hi_r6_r7_LSR_29[] = {
  0x88, 0xbf, 0x7e, 0x0f // It hi; mov hi r6 r7 LSR 29
};
const byte kInstruction_mov_mi_r7_r1_LSR_10[] = {
  0x48, 0xbf, 0x8f, 0x0a // It mi; mov mi r7 r1 LSR 10
};
const byte kInstruction_mov_ls_r7_r6_LSR_14[] = {
  0x98, 0xbf, 0xb7, 0x0b // It ls; mov ls r7 r6 LSR 14
};
const byte kInstruction_mov_eq_r7_r2_ASR_14[] = {
  0x08, 0xbf, 0x97, 0x13 // It eq; mov eq r7 r2 ASR 14
};
const byte kInstruction_mov_le_r3_r7_LSR_2[] = {
  0xd8, 0xbf, 0xbb, 0x08 // It le; mov le r3 r7 LSR 2
};
const byte kInstruction_mov_mi_r2_r7_LSR_32[] = {
  0x48, 0xbf, 0x3a, 0x08 // It mi; mov mi r2 r7 LSR 32
};
const byte kInstruction_mov_ge_r5_r0_ASR_23[] = {
  0xa8, 0xbf, 0xc5, 0x15 // It ge; mov ge r5 r0 ASR 23
};
const byte kInstruction_mov_ne_r3_r7_LSR_28[] = {
  0x18, 0xbf, 0x3b, 0x0f // It ne; mov ne r3 r7 LSR 28
};
const byte kInstruction_mov_gt_r6_r4_LSR_13[] = {
  0xc8, 0xbf, 0x66, 0x0b // It gt; mov gt r6 r4 LSR 13
};
const byte kInstruction_mov_hi_r6_r5_LSR_12[] = {
  0x88, 0xbf, 0x2e, 0x0b // It hi; mov hi r6 r5 LSR 12
};
const byte kInstruction_mov_pl_r6_r1_ASR_12[] = {
  0x58, 0xbf, 0x0e, 0x13 // It pl; mov pl r6 r1 ASR 12
};
const byte kInstruction_mov_hi_r7_r1_ASR_30[] = {
  0x88, 0xbf, 0x8f, 0x17 // It hi; mov hi r7 r1 ASR 30
};
const byte kInstruction_mov_mi_r7_r6_ASR_20[] = {
  0x48, 0xbf, 0x37, 0x15 // It mi; mov mi r7 r6 ASR 20
};
const byte kInstruction_mov_cc_r3_r6_ASR_22[] = {
  0x38, 0xbf, 0xb3, 0x15 // It cc; mov cc r3 r6 ASR 22
};
const byte kInstruction_mov_vc_r2_r1_ASR_29[] = {
  0x78, 0xbf, 0x4a, 0x17 // It vc; mov vc r2 r1 ASR 29
};
const byte kInstruction_mov_pl_r0_r1_ASR_15[] = {
  0x58, 0xbf, 0xc8, 0x13 // It pl; mov pl r0 r1 ASR 15
};
const byte kInstruction_mov_mi_r2_r1_LSR_22[] = {
  0x48, 0xbf, 0x8a, 0x0d // It mi; mov mi r2 r1 LSR 22
};
const byte kInstruction_mov_pl_r6_r4_ASR_6[] = {
  0x58, 0xbf, 0xa6, 0x11 // It pl; mov pl r6 r4 ASR 6
};
const byte kInstruction_mov_hi_r1_r3_ASR_15[] = {
  0x88, 0xbf, 0xd9, 0x13 // It hi; mov hi r1 r3 ASR 15
};
const byte kInstruction_mov_eq_r3_r5_ASR_13[] = {
  0x08, 0xbf, 0x6b, 0x13 // It eq; mov eq r3 r5 ASR 13
};
const byte kInstruction_mov_le_r4_r6_ASR_31[] = {
  0xd8, 0xbf, 0xf4, 0x17 // It le; mov le r4 r6 ASR 31
};
const byte kInstruction_mov_gt_r5_r1_ASR_15[] = {
  0xc8, 0xbf, 0xcd, 0x13 // It gt; mov gt r5 r1 ASR 15
};
const byte kInstruction_mov_pl_r3_r7_ASR_29[] = {
  0x58, 0xbf, 0x7b, 0x17 // It pl; mov pl r3 r7 ASR 29
};
const byte kInstruction_mov_cs_r3_r1_ASR_15[] = {
  0x28, 0xbf, 0xcb, 0x13 // It cs; mov cs r3 r1 ASR 15
};
const byte kInstruction_mov_le_r1_r7_ASR_32[] = {
  0xd8, 0xbf, 0x39, 0x10 // It le; mov le r1 r7 ASR 32
};
const byte kInstruction_mov_vs_r5_r7_LSR_5[] = {
  0x68, 0xbf, 0x7d, 0x09 // It vs; mov vs r5 r7 LSR 5
};
const byte kInstruction_mov_cs_r3_r1_ASR_30[] = {
  0x28, 0xbf, 0x8b, 0x17 // It cs; mov cs r3 r1 ASR 30
};
const byte kInstruction_mov_gt_r7_r0_LSR_26[] = {
  0xc8, 0xbf, 0x87, 0x0e // It gt; mov gt r7 r0 LSR 26
};
const byte kInstruction_mov_ne_r2_r6_LSR_24[] = {
  0x18, 0xbf, 0x32, 0x0e // It ne; mov ne r2 r6 LSR 24
};
const byte kInstruction_mov_pl_r2_r3_ASR_5[] = {
  0x58, 0xbf, 0x5a, 0x11 // It pl; mov pl r2 r3 ASR 5
};
const byte kInstruction_mov_le_r3_r4_ASR_30[] = {
  0xd8, 0xbf, 0xa3, 0x17 // It le; mov le r3 r4 ASR 30
};
const byte kInstruction_mov_cs_r5_r7_ASR_13[] = {
  0x28, 0xbf, 0x7d, 0x13 // It cs; mov cs r5 r7 ASR 13
};
const byte kInstruction_mov_eq_r0_r1_LSR_31[] = {
  0x08, 0xbf, 0xc8, 0x0f // It eq; mov eq r0 r1 LSR 31
};
const byte kInstruction_mov_eq_r7_r2_LSR_2[] = {
  0x08, 0xbf, 0x97, 0x08 // It eq; mov eq r7 r2 LSR 2
};
const byte kInstruction_mov_vc_r2_r5_ASR_30[] = {
  0x78, 0xbf, 0xaa, 0x17 // It vc; mov vc r2 r5 ASR 30
};
const byte kInstruction_mov_eq_r2_r1_ASR_5[] = {
  0x08, 0xbf, 0x4a, 0x11 // It eq; mov eq r2 r1 ASR 5
};
const byte kInstruction_mov_le_r4_r7_LSR_10[] = {
  0xd8, 0xbf, 0xbc, 0x0a // It le; mov le r4 r7 LSR 10
};
const byte kInstruction_mov_cs_r6_r1_ASR_13[] = {
  0x28, 0xbf, 0x4e, 0x13 // It cs; mov cs r6 r1 ASR 13
};
const byte kInstruction_mov_ls_r7_r4_LSR_26[] = {
  0x98, 0xbf, 0xa7, 0x0e // It ls; mov ls r7 r4 LSR 26
};
const byte kInstruction_mov_ge_r7_r3_ASR_28[] = {
  0xa8, 0xbf, 0x1f, 0x17 // It ge; mov ge r7 r3 ASR 28
};
const byte kInstruction_mov_mi_r4_r4_LSR_16[] = {
  0x48, 0xbf, 0x24, 0x0c // It mi; mov mi r4 r4 LSR 16
};
const byte kInstruction_mov_ge_r3_r7_LSR_23[] = {
  0xa8, 0xbf, 0xfb, 0x0d // It ge; mov ge r3 r7 LSR 23
};
const byte kInstruction_mov_ge_r3_r3_LSR_25[] = {
  0xa8, 0xbf, 0x5b, 0x0e // It ge; mov ge r3 r3 LSR 25
};
const byte kInstruction_mov_ne_r2_r2_ASR_19[] = {
  0x18, 0xbf, 0xd2, 0x14 // It ne; mov ne r2 r2 ASR 19
};
const byte kInstruction_mov_hi_r0_r5_LSR_29[] = {
  0x88, 0xbf, 0x68, 0x0f // It hi; mov hi r0 r5 LSR 29
};
const byte kInstruction_mov_vc_r0_r0_ASR_18[] = {
  0x78, 0xbf, 0x80, 0x14 // It vc; mov vc r0 r0 ASR 18
};
const byte kInstruction_mov_gt_r5_r3_ASR_3[] = {
  0xc8, 0xbf, 0xdd, 0x10 // It gt; mov gt r5 r3 ASR 3
};
const byte kInstruction_mov_mi_r6_r2_ASR_28[] = {
  0x48, 0xbf, 0x16, 0x17 // It mi; mov mi r6 r2 ASR 28
};
const byte kInstruction_mov_ls_r2_r6_LSR_31[] = {
  0x98, 0xbf, 0xf2, 0x0f // It ls; mov ls r2 r6 LSR 31
};
const byte kInstruction_mov_cs_r4_r0_LSR_5[] = {
  0x28, 0xbf, 0x44, 0x09 // It cs; mov cs r4 r0 LSR 5
};
const byte kInstruction_mov_eq_r6_r2_ASR_17[] = {
  0x08, 0xbf, 0x56, 0x14 // It eq; mov eq r6 r2 ASR 17
};
const byte kInstruction_mov_cs_r7_r5_LSR_2[] = {
  0x28, 0xbf, 0xaf, 0x08 // It cs; mov cs r7 r5 LSR 2
};
const byte kInstruction_mov_vc_r5_r3_LSR_17[] = {
  0x78, 0xbf, 0x5d, 0x0c // It vc; mov vc r5 r3 LSR 17
};
const byte kInstruction_mov_pl_r5_r1_LSR_12[] = {
  0x58, 0xbf, 0x0d, 0x0b // It pl; mov pl r5 r1 LSR 12
};
const byte kInstruction_mov_lt_r2_r1_LSR_2[] = {
  0xb8, 0xbf, 0x8a, 0x08 // It lt; mov lt r2 r1 LSR 2
};
const byte kInstruction_mov_hi_r6_r5_ASR_3[] = {
  0x88, 0xbf, 0xee, 0x10 // It hi; mov hi r6 r5 ASR 3
};
const byte kInstruction_mov_gt_r1_r6_ASR_19[] = {
  0xc8, 0xbf, 0xf1, 0x14 // It gt; mov gt r1 r6 ASR 19
};
const byte kInstruction_mov_ne_r3_r7_ASR_24[] = {
  0x18, 0xbf, 0x3b, 0x16 // It ne; mov ne r3 r7 ASR 24
};
const byte kInstruction_mov_mi_r3_r2_ASR_27[] = {
  0x48, 0xbf, 0xd3, 0x16 // It mi; mov mi r3 r2 ASR 27
};
const byte kInstruction_mov_ge_r0_r5_ASR_24[] = {
  0xa8, 0xbf, 0x28, 0x16 // It ge; mov ge r0 r5 ASR 24
};
const byte kInstruction_mov_hi_r0_r2_ASR_12[] = {
  0x88, 0xbf, 0x10, 0x13 // It hi; mov hi r0 r2 ASR 12
};
const byte kInstruction_mov_vs_r4_r7_LSR_8[] = {
  0x68, 0xbf, 0x3c, 0x0a // It vs; mov vs r4 r7 LSR 8
};
const byte kInstruction_mov_vc_r0_r4_LSR_6[] = {
  0x78, 0xbf, 0xa0, 0x09 // It vc; mov vc r0 r4 LSR 6
};
const byte kInstruction_mov_cs_r3_r7_LSR_2[] = {
  0x28, 0xbf, 0xbb, 0x08 // It cs; mov cs r3 r7 LSR 2
};
const byte kInstruction_mov_cc_r2_r3_ASR_7[] = {
  0x38, 0xbf, 0xda, 0x11 // It cc; mov cc r2 r3 ASR 7
};
const byte kInstruction_mov_lt_r5_r4_LSR_26[] = {
  0xb8, 0xbf, 0xa5, 0x0e // It lt; mov lt r5 r4 LSR 26
};
const byte kInstruction_mov_vs_r6_r3_LSR_16[] = {
  0x68, 0xbf, 0x1e, 0x0c // It vs; mov vs r6 r3 LSR 16
};
const byte kInstruction_mov_hi_r5_r3_ASR_19[] = {
  0x88, 0xbf, 0xdd, 0x14 // It hi; mov hi r5 r3 ASR 19
};
const byte kInstruction_mov_cc_r3_r6_LSR_16[] = {
  0x38, 0xbf, 0x33, 0x0c // It cc; mov cc r3 r6 LSR 16
};
const byte kInstruction_mov_cc_r0_r6_LSR_31[] = {
  0x38, 0xbf, 0xf0, 0x0f // It cc; mov cc r0 r6 LSR 31
};
const byte kInstruction_mov_hi_r6_r7_ASR_32[] = {
  0x88, 0xbf, 0x3e, 0x10 // It hi; mov hi r6 r7 ASR 32
};
const byte kInstruction_mov_vc_r3_r4_ASR_12[] = {
  0x78, 0xbf, 0x23, 0x13 // It vc; mov vc r3 r4 ASR 12
};
const byte kInstruction_mov_cs_r5_r7_ASR_9[] = {
  0x28, 0xbf, 0x7d, 0x12 // It cs; mov cs r5 r7 ASR 9
};
const byte kInstruction_mov_lt_r5_r0_ASR_4[] = {
  0xb8, 0xbf, 0x05, 0x11 // It lt; mov lt r5 r0 ASR 4
};
const byte kInstruction_mov_cc_r3_r1_ASR_17[] = {
  0x38, 0xbf, 0x4b, 0x14 // It cc; mov cc r3 r1 ASR 17
};
const byte kInstruction_mov_vs_r7_r4_ASR_16[] = {
  0x68, 0xbf, 0x27, 0x14 // It vs; mov vs r7 r4 ASR 16
};
const byte kInstruction_mov_eq_r7_r6_ASR_14[] = {
  0x08, 0xbf, 0xb7, 0x13 // It eq; mov eq r7 r6 ASR 14
};
const byte kInstruction_mov_ne_r1_r0_ASR_21[] = {
  0x18, 0xbf, 0x41, 0x15 // It ne; mov ne r1 r0 ASR 21
};
const byte kInstruction_mov_ls_r0_r1_LSR_19[] = {
  0x98, 0xbf, 0xc8, 0x0c // It ls; mov ls r0 r1 LSR 19
};
const byte kInstruction_mov_cc_r1_r7_ASR_6[] = {
  0x38, 0xbf, 0xb9, 0x11 // It cc; mov cc r1 r7 ASR 6
};
const byte kInstruction_mov_lt_r5_r2_LSR_1[] = {
  0xb8, 0xbf, 0x55, 0x08 // It lt; mov lt r5 r2 LSR 1
};
const byte kInstruction_mov_lt_r7_r0_LSR_13[] = {
  0xb8, 0xbf, 0x47, 0x0b // It lt; mov lt r7 r0 LSR 13
};
const byte kInstruction_mov_gt_r2_r6_ASR_14[] = {
  0xc8, 0xbf, 0xb2, 0x13 // It gt; mov gt r2 r6 ASR 14
};
const byte kInstruction_mov_ls_r5_r5_ASR_23[] = {
  0x98, 0xbf, 0xed, 0x15 // It ls; mov ls r5 r5 ASR 23
};
const byte kInstruction_mov_cs_r1_r1_ASR_12[] = {
  0x28, 0xbf, 0x09, 0x13 // It cs; mov cs r1 r1 ASR 12
};
const byte kInstruction_mov_pl_r0_r2_LSR_3[] = {
  0x58, 0xbf, 0xd0, 0x08 // It pl; mov pl r0 r2 LSR 3
};
const byte kInstruction_mov_le_r0_r1_LSR_5[] = {
  0xd8, 0xbf, 0x48, 0x09 // It le; mov le r0 r1 LSR 5
};
const byte kInstruction_mov_ne_r0_r5_LSR_29[] = {
  0x18, 0xbf, 0x68, 0x0f // It ne; mov ne r0 r5 LSR 29
};
const byte kInstruction_mov_vs_r6_r5_LSR_14[] = {
  0x68, 0xbf, 0xae, 0x0b // It vs; mov vs r6 r5 LSR 14
};
const byte kInstruction_mov_hi_r1_r7_ASR_25[] = {
  0x88, 0xbf, 0x79, 0x16 // It hi; mov hi r1 r7 ASR 25
};
const byte kInstruction_mov_mi_r2_r5_ASR_24[] = {
  0x48, 0xbf, 0x2a, 0x16 // It mi; mov mi r2 r5 ASR 24
};
const byte kInstruction_mov_vc_r3_r4_ASR_3[] = {
  0x78, 0xbf, 0xe3, 0x10 // It vc; mov vc r3 r4 ASR 3
};
const byte kInstruction_mov_cs_r4_r0_LSR_29[] = {
  0x28, 0xbf, 0x44, 0x0f // It cs; mov cs r4 r0 LSR 29
};
const byte kInstruction_mov_ne_r6_r6_ASR_24[] = {
  0x18, 0xbf, 0x36, 0x16 // It ne; mov ne r6 r6 ASR 24
};
const byte kInstruction_mov_lt_r1_r1_LSR_1[] = {
  0xb8, 0xbf, 0x49, 0x08 // It lt; mov lt r1 r1 LSR 1
};
const byte kInstruction_mov_gt_r5_r3_ASR_8[] = {
  0xc8, 0xbf, 0x1d, 0x12 // It gt; mov gt r5 r3 ASR 8
};
const byte kInstruction_mov_mi_r4_r3_LSR_10[] = {
  0x48, 0xbf, 0x9c, 0x0a // It mi; mov mi r4 r3 LSR 10
};
const byte kInstruction_mov_ge_r0_r4_LSR_24[] = {
  0xa8, 0xbf, 0x20, 0x0e // It ge; mov ge r0 r4 LSR 24
};
const byte kInstruction_mov_hi_r0_r5_LSR_17[] = {
  0x88, 0xbf, 0x68, 0x0c // It hi; mov hi r0 r5 LSR 17
};
const byte kInstruction_mov_gt_r6_r7_ASR_12[] = {
  0xc8, 0xbf, 0x3e, 0x13 // It gt; mov gt r6 r7 ASR 12
};
const byte kInstruction_mov_mi_r2_r2_LSR_15[] = {
  0x48, 0xbf, 0xd2, 0x0b // It mi; mov mi r2 r2 LSR 15
};
const byte kInstruction_mov_ls_r3_r0_ASR_1[] = {
  0x98, 0xbf, 0x43, 0x10 // It ls; mov ls r3 r0 ASR 1
};
const byte kInstruction_mov_lt_r4_r0_LSR_5[] = {
  0xb8, 0xbf, 0x44, 0x09 // It lt; mov lt r4 r0 LSR 5
};
const byte kInstruction_mov_hi_r0_r1_LSR_18[] = {
  0x88, 0xbf, 0x88, 0x0c // It hi; mov hi r0 r1 LSR 18
};
const byte kInstruction_mov_hi_r6_r4_LSR_28[] = {
  0x88, 0xbf, 0x26, 0x0f // It hi; mov hi r6 r4 LSR 28
};
const byte kInstruction_mov_pl_r1_r1_LSR_24[] = {
  0x58, 0xbf, 0x09, 0x0e // It pl; mov pl r1 r1 LSR 24
};
const byte kInstruction_mov_vs_r6_r0_ASR_8[] = {
  0x68, 0xbf, 0x06, 0x12 // It vs; mov vs r6 r0 ASR 8
};
const byte kInstruction_mov_vs_r3_r4_LSR_8[] = {
  0x68, 0xbf, 0x23, 0x0a // It vs; mov vs r3 r4 LSR 8
};
const byte kInstruction_mov_cs_r2_r6_LSR_13[] = {
  0x28, 0xbf, 0x72, 0x0b // It cs; mov cs r2 r6 LSR 13
};
const byte kInstruction_mov_lt_r7_r6_ASR_15[] = {
  0xb8, 0xbf, 0xf7, 0x13 // It lt; mov lt r7 r6 ASR 15
};
const byte kInstruction_mov_le_r6_r1_ASR_32[] = {
  0xd8, 0xbf, 0x0e, 0x10 // It le; mov le r6 r1 ASR 32
};
const byte kInstruction_mov_cc_r7_r5_LSR_3[] = {
  0x38, 0xbf, 0xef, 0x08 // It cc; mov cc r7 r5 LSR 3
};
const byte kInstruction_mov_hi_r5_r1_LSR_7[] = {
  0x88, 0xbf, 0xcd, 0x09 // It hi; mov hi r5 r1 LSR 7
};
const byte kInstruction_mov_lt_r5_r4_LSR_5[] = {
  0xb8, 0xbf, 0x65, 0x09 // It lt; mov lt r5 r4 LSR 5
};
const byte kInstruction_mov_mi_r4_r2_LSR_9[] = {
  0x48, 0xbf, 0x54, 0x0a // It mi; mov mi r4 r2 LSR 9
};
const byte kInstruction_mov_pl_r3_r3_ASR_10[] = {
  0x58, 0xbf, 0x9b, 0x12 // It pl; mov pl r3 r3 ASR 10
};
const byte kInstruction_mov_ge_r3_r7_LSR_17[] = {
  0xa8, 0xbf, 0x7b, 0x0c // It ge; mov ge r3 r7 LSR 17
};
const byte kInstruction_mov_ls_r4_r1_LSR_5[] = {
  0x98, 0xbf, 0x4c, 0x09 // It ls; mov ls r4 r1 LSR 5
};
const byte kInstruction_mov_mi_r4_r3_LSR_28[] = {
  0x48, 0xbf, 0x1c, 0x0f // It mi; mov mi r4 r3 LSR 28
};
const byte kInstruction_mov_ne_r7_r1_ASR_14[] = {
  0x18, 0xbf, 0x8f, 0x13 // It ne; mov ne r7 r1 ASR 14
};
const byte kInstruction_mov_ge_r7_r7_ASR_20[] = {
  0xa8, 0xbf, 0x3f, 0x15 // It ge; mov ge r7 r7 ASR 20
};
const byte kInstruction_mov_ne_r2_r3_LSR_11[] = {
  0x18, 0xbf, 0xda, 0x0a // It ne; mov ne r2 r3 LSR 11
};
const byte kInstruction_mov_lt_r6_r5_ASR_15[] = {
  0xb8, 0xbf, 0xee, 0x13 // It lt; mov lt r6 r5 ASR 15
};
const byte kInstruction_mov_cs_r6_r7_ASR_3[] = {
  0x28, 0xbf, 0xfe, 0x10 // It cs; mov cs r6 r7 ASR 3
};
const byte kInstruction_mov_hi_r7_r7_LSR_12[] = {
  0x88, 0xbf, 0x3f, 0x0b // It hi; mov hi r7 r7 LSR 12
};
const byte kInstruction_mov_cs_r2_r4_ASR_4[] = {
  0x28, 0xbf, 0x22, 0x11 // It cs; mov cs r2 r4 ASR 4
};
const byte kInstruction_mov_lt_r7_r7_ASR_3[] = {
  0xb8, 0xbf, 0xff, 0x10 // It lt; mov lt r7 r7 ASR 3
};
const byte kInstruction_mov_le_r1_r3_ASR_27[] = {
  0xd8, 0xbf, 0xd9, 0x16 // It le; mov le r1 r3 ASR 27
};
const byte kInstruction_mov_vs_r2_r3_LSR_28[] = {
  0x68, 0xbf, 0x1a, 0x0f // It vs; mov vs r2 r3 LSR 28
};
const byte kInstruction_mov_pl_r2_r0_ASR_8[] = {
  0x58, 0xbf, 0x02, 0x12 // It pl; mov pl r2 r0 ASR 8
};
const byte kInstruction_mov_hi_r5_r2_ASR_15[] = {
  0x88, 0xbf, 0xd5, 0x13 // It hi; mov hi r5 r2 ASR 15
};
const byte kInstruction_mov_vs_r6_r0_LSR_5[] = {
  0x68, 0xbf, 0x46, 0x09 // It vs; mov vs r6 r0 LSR 5
};
const byte kInstruction_mov_le_r1_r6_ASR_22[] = {
  0xd8, 0xbf, 0xb1, 0x15 // It le; mov le r1 r6 ASR 22
};
const byte kInstruction_mov_hi_r3_r2_ASR_17[] = {
  0x88, 0xbf, 0x53, 0x14 // It hi; mov hi r3 r2 ASR 17
};
const byte kInstruction_mov_gt_r1_r5_ASR_16[] = {
  0xc8, 0xbf, 0x29, 0x14 // It gt; mov gt r1 r5 ASR 16
};
const byte kInstruction_mov_hi_r2_r0_ASR_26[] = {
  0x88, 0xbf, 0x82, 0x16 // It hi; mov hi r2 r0 ASR 26
};
const byte kInstruction_mov_vs_r1_r4_LSR_27[] = {
  0x68, 0xbf, 0xe1, 0x0e // It vs; mov vs r1 r4 LSR 27
};
const byte kInstruction_mov_ls_r3_r4_ASR_15[] = {
  0x98, 0xbf, 0xe3, 0x13 // It ls; mov ls r3 r4 ASR 15
};
const byte kInstruction_mov_ge_r7_r4_LSR_15[] = {
  0xa8, 0xbf, 0xe7, 0x0b // It ge; mov ge r7 r4 LSR 15
};
const byte kInstruction_mov_vc_r7_r2_LSR_21[] = {
  0x78, 0xbf, 0x57, 0x0d // It vc; mov vc r7 r2 LSR 21
};
const byte kInstruction_mov_ls_r2_r7_ASR_22[] = {
  0x98, 0xbf, 0xba, 0x15 // It ls; mov ls r2 r7 ASR 22
};
const byte kInstruction_mov_pl_r5_r5_LSR_21[] = {
  0x58, 0xbf, 0x6d, 0x0d // It pl; mov pl r5 r5 LSR 21
};
const byte kInstruction_mov_cs_r2_r4_ASR_25[] = {
  0x28, 0xbf, 0x62, 0x16 // It cs; mov cs r2 r4 ASR 25
};
const byte kInstruction_mov_gt_r7_r6_LSR_5[] = {
  0xc8, 0xbf, 0x77, 0x09 // It gt; mov gt r7 r6 LSR 5
};
const byte kInstruction_mov_gt_r5_r6_ASR_25[] = {
  0xc8, 0xbf, 0x75, 0x16 // It gt; mov gt r5 r6 ASR 25
};
const byte kInstruction_mov_vs_r3_r0_LSR_30[] = {
  0x68, 0xbf, 0x83, 0x0f // It vs; mov vs r3 r0 LSR 30
};
const byte kInstruction_mov_pl_r6_r0_LSR_17[] = {
  0x58, 0xbf, 0x46, 0x0c // It pl; mov pl r6 r0 LSR 17
};
const byte kInstruction_mov_pl_r6_r2_ASR_7[] = {
  0x58, 0xbf, 0xd6, 0x11 // It pl; mov pl r6 r2 ASR 7
};
const byte kInstruction_mov_lt_r4_r4_LSR_17[] = {
  0xb8, 0xbf, 0x64, 0x0c // It lt; mov lt r4 r4 LSR 17
};
const byte kInstruction_mov_vc_r4_r5_LSR_3[] = {
  0x78, 0xbf, 0xec, 0x08 // It vc; mov vc r4 r5 LSR 3
};
const byte kInstruction_mov_cc_r4_r4_ASR_21[] = {
  0x38, 0xbf, 0x64, 0x15 // It cc; mov cc r4 r4 ASR 21
};
const byte kInstruction_mov_vs_r4_r2_ASR_10[] = {
  0x68, 0xbf, 0x94, 0x12 // It vs; mov vs r4 r2 ASR 10
};
const byte kInstruction_mov_cs_r7_r4_ASR_10[] = {
  0x28, 0xbf, 0xa7, 0x12 // It cs; mov cs r7 r4 ASR 10
};
const byte kInstruction_mov_hi_r6_r1_LSR_17[] = {
  0x88, 0xbf, 0x4e, 0x0c // It hi; mov hi r6 r1 LSR 17
};
const byte kInstruction_mov_vc_r4_r6_LSR_24[] = {
  0x78, 0xbf, 0x34, 0x0e // It vc; mov vc r4 r6 LSR 24
};
const byte kInstruction_mov_pl_r3_r2_ASR_7[] = {
  0x58, 0xbf, 0xd3, 0x11 // It pl; mov pl r3 r2 ASR 7
};
const byte kInstruction_mov_mi_r3_r7_LSR_17[] = {
  0x48, 0xbf, 0x7b, 0x0c // It mi; mov mi r3 r7 LSR 17
};
const byte kInstruction_mov_pl_r7_r3_ASR_7[] = {
  0x58, 0xbf, 0xdf, 0x11 // It pl; mov pl r7 r3 ASR 7
};
const byte kInstruction_mov_vc_r0_r4_LSR_10[] = {
  0x78, 0xbf, 0xa0, 0x0a // It vc; mov vc r0 r4 LSR 10
};
const byte kInstruction_mov_le_r2_r1_ASR_24[] = {
  0xd8, 0xbf, 0x0a, 0x16 // It le; mov le r2 r1 ASR 24
};
const byte kInstruction_mov_le_r2_r7_LSR_11[] = {
  0xd8, 0xbf, 0xfa, 0x0a // It le; mov le r2 r7 LSR 11
};
const byte kInstruction_mov_cs_r6_r0_ASR_13[] = {
  0x28, 0xbf, 0x46, 0x13 // It cs; mov cs r6 r0 ASR 13
};
const byte kInstruction_mov_ge_r3_r0_ASR_27[] = {
  0xa8, 0xbf, 0xc3, 0x16 // It ge; mov ge r3 r0 ASR 27
};
const byte kInstruction_mov_cc_r6_r0_ASR_17[] = {
  0x38, 0xbf, 0x46, 0x14 // It cc; mov cc r6 r0 ASR 17
};
const byte kInstruction_mov_hi_r7_r7_ASR_6[] = {
  0x88, 0xbf, 0xbf, 0x11 // It hi; mov hi r7 r7 ASR 6
};
const byte kInstruction_mov_vc_r6_r7_LSR_21[] = {
  0x78, 0xbf, 0x7e, 0x0d // It vc; mov vc r6 r7 LSR 21
};
const byte kInstruction_mov_ge_r6_r4_ASR_25[] = {
  0xa8, 0xbf, 0x66, 0x16 // It ge; mov ge r6 r4 ASR 25
};
const byte kInstruction_mov_gt_r5_r2_ASR_7[] = {
  0xc8, 0xbf, 0xd5, 0x11 // It gt; mov gt r5 r2 ASR 7
};
const byte kInstruction_mov_gt_r6_r1_LSR_8[] = {
  0xc8, 0xbf, 0x0e, 0x0a // It gt; mov gt r6 r1 LSR 8
};
const byte kInstruction_mov_le_r1_r6_ASR_13[] = {
  0xd8, 0xbf, 0x71, 0x13 // It le; mov le r1 r6 ASR 13
};
const byte kInstruction_mov_hi_r6_r0_ASR_24[] = {
  0x88, 0xbf, 0x06, 0x16 // It hi; mov hi r6 r0 ASR 24
};
const byte kInstruction_mov_le_r1_r5_ASR_29[] = {
  0xd8, 0xbf, 0x69, 0x17 // It le; mov le r1 r5 ASR 29
};
const byte kInstruction_mov_vs_r5_r1_ASR_23[] = {
  0x68, 0xbf, 0xcd, 0x15 // It vs; mov vs r5 r1 ASR 23
};
const byte kInstruction_mov_le_r0_r6_LSR_7[] = {
  0xd8, 0xbf, 0xf0, 0x09 // It le; mov le r0 r6 LSR 7
};
const byte kInstruction_mov_pl_r7_r1_LSR_17[] = {
  0x58, 0xbf, 0x4f, 0x0c // It pl; mov pl r7 r1 LSR 17
};
const byte kInstruction_mov_ne_r4_r7_ASR_5[] = {
  0x18, 0xbf, 0x7c, 0x11 // It ne; mov ne r4 r7 ASR 5
};
const byte kInstruction_mov_ne_r5_r5_LSR_22[] = {
  0x18, 0xbf, 0xad, 0x0d // It ne; mov ne r5 r5 LSR 22
};
const byte kInstruction_mov_lt_r7_r2_ASR_29[] = {
  0xb8, 0xbf, 0x57, 0x17 // It lt; mov lt r7 r2 ASR 29
};
const byte kInstruction_mov_le_r5_r3_LSR_28[] = {
  0xd8, 0xbf, 0x1d, 0x0f // It le; mov le r5 r3 LSR 28
};
const byte kInstruction_mov_eq_r7_r5_ASR_29[] = {
  0x08, 0xbf, 0x6f, 0x17 // It eq; mov eq r7 r5 ASR 29
};
const byte kInstruction_mov_cs_r2_r6_LSR_4[] = {
  0x28, 0xbf, 0x32, 0x09 // It cs; mov cs r2 r6 LSR 4
};
const byte kInstruction_mov_ne_r1_r0_LSR_17[] = {
  0x18, 0xbf, 0x41, 0x0c // It ne; mov ne r1 r0 LSR 17
};
const byte kInstruction_mov_ls_r2_r6_ASR_28[] = {
  0x98, 0xbf, 0x32, 0x17 // It ls; mov ls r2 r6 ASR 28
};
const byte kInstruction_mov_ge_r5_r7_ASR_32[] = {
  0xa8, 0xbf, 0x3d, 0x10 // It ge; mov ge r5 r7 ASR 32
};
const byte kInstruction_mov_cs_r0_r0_ASR_1[] = {
  0x28, 0xbf, 0x40, 0x10 // It cs; mov cs r0 r0 ASR 1
};
const byte kInstruction_mov_mi_r6_r5_LSR_11[] = {
  0x48, 0xbf, 0xee, 0x0a // It mi; mov mi r6 r5 LSR 11
};
const byte kInstruction_mov_mi_r5_r3_ASR_29[] = {
  0x48, 0xbf, 0x5d, 0x17 // It mi; mov mi r5 r3 ASR 29
};
const byte kInstruction_mov_eq_r2_r2_LSR_30[] = {
  0x08, 0xbf, 0x92, 0x0f // It eq; mov eq r2 r2 LSR 30
};
const byte kInstruction_mov_mi_r4_r2_ASR_25[] = {
  0x48, 0xbf, 0x54, 0x16 // It mi; mov mi r4 r2 ASR 25
};
const byte kInstruction_mov_cs_r5_r0_LSR_13[] = {
  0x28, 0xbf, 0x45, 0x0b // It cs; mov cs r5 r0 LSR 13
};
const byte kInstruction_mov_cc_r7_r4_ASR_10[] = {
  0x38, 0xbf, 0xa7, 0x12 // It cc; mov cc r7 r4 ASR 10
};
const byte kInstruction_mov_mi_r1_r5_LSR_21[] = {
  0x48, 0xbf, 0x69, 0x0d // It mi; mov mi r1 r5 LSR 21
};
const byte kInstruction_mov_vs_r3_r2_LSR_2[] = {
  0x68, 0xbf, 0x93, 0x08 // It vs; mov vs r3 r2 LSR 2
};
const byte kInstruction_mov_ls_r4_r4_ASR_14[] = {
  0x98, 0xbf, 0xa4, 0x13 // It ls; mov ls r4 r4 ASR 14
};
const byte kInstruction_mov_eq_r5_r4_LSR_23[] = {
  0x08, 0xbf, 0xe5, 0x0d // It eq; mov eq r5 r4 LSR 23
};
const byte kInstruction_mov_gt_r7_r1_ASR_20[] = {
  0xc8, 0xbf, 0x0f, 0x15 // It gt; mov gt r7 r1 ASR 20
};
const byte kInstruction_mov_vs_r2_r5_ASR_5[] = {
  0x68, 0xbf, 0x6a, 0x11 // It vs; mov vs r2 r5 ASR 5
};
const byte kInstruction_mov_le_r6_r0_LSR_14[] = {
  0xd8, 0xbf, 0x86, 0x0b // It le; mov le r6 r0 LSR 14
};
const byte kInstruction_mov_cs_r6_r5_LSR_14[] = {
  0x28, 0xbf, 0xae, 0x0b // It cs; mov cs r6 r5 LSR 14
};
const byte kInstruction_mov_ls_r7_r4_ASR_22[] = {
  0x98, 0xbf, 0xa7, 0x15 // It ls; mov ls r7 r4 ASR 22
};
const byte kInstruction_mov_cs_r3_r2_ASR_1[] = {
  0x28, 0xbf, 0x53, 0x10 // It cs; mov cs r3 r2 ASR 1
};
const byte kInstruction_mov_ne_r7_r1_LSR_30[] = {
  0x18, 0xbf, 0x8f, 0x0f // It ne; mov ne r7 r1 LSR 30
};
const byte kInstruction_mov_ge_r3_r6_LSR_32[] = {
  0xa8, 0xbf, 0x33, 0x08 // It ge; mov ge r3 r6 LSR 32
};
const byte kInstruction_mov_ne_r2_r5_ASR_11[] = {
  0x18, 0xbf, 0xea, 0x12 // It ne; mov ne r2 r5 ASR 11
};
const byte kInstruction_mov_cc_r4_r4_LSR_4[] = {
  0x38, 0xbf, 0x24, 0x09 // It cc; mov cc r4 r4 LSR 4
};
const byte kInstruction_mov_lt_r6_r0_ASR_31[] = {
  0xb8, 0xbf, 0xc6, 0x17 // It lt; mov lt r6 r0 ASR 31
};
const byte kInstruction_mov_cc_r7_r0_LSR_26[] = {
  0x38, 0xbf, 0x87, 0x0e // It cc; mov cc r7 r0 LSR 26
};
const byte kInstruction_mov_vs_r1_r4_LSR_31[] = {
  0x68, 0xbf, 0xe1, 0x0f // It vs; mov vs r1 r4 LSR 31
};
const byte kInstruction_mov_vc_r3_r6_LSR_11[] = {
  0x78, 0xbf, 0xf3, 0x0a // It vc; mov vc r3 r6 LSR 11
};
const byte kInstruction_mov_cs_r0_r4_LSR_26[] = {
  0x28, 0xbf, 0xa0, 0x0e // It cs; mov cs r0 r4 LSR 26
};
const byte kInstruction_mov_eq_r0_r6_ASR_31[] = {
  0x08, 0xbf, 0xf0, 0x17 // It eq; mov eq r0 r6 ASR 31
};
const byte kInstruction_mov_eq_r0_r1_ASR_27[] = {
  0x08, 0xbf, 0xc8, 0x16 // It eq; mov eq r0 r1 ASR 27
};
const byte kInstruction_mov_ls_r2_r0_LSR_16[] = {
  0x98, 0xbf, 0x02, 0x0c // It ls; mov ls r2 r0 LSR 16
};
const byte kInstruction_mov_vs_r1_r7_LSR_10[] = {
  0x68, 0xbf, 0xb9, 0x0a // It vs; mov vs r1 r7 LSR 10
};
const byte kInstruction_mov_gt_r1_r2_ASR_7[] = {
  0xc8, 0xbf, 0xd1, 0x11 // It gt; mov gt r1 r2 ASR 7
};
const byte kInstruction_mov_vc_r6_r5_LSR_6[] = {
  0x78, 0xbf, 0xae, 0x09 // It vc; mov vc r6 r5 LSR 6
};
const byte kInstruction_mov_ge_r7_r2_ASR_4[] = {
  0xa8, 0xbf, 0x17, 0x11 // It ge; mov ge r7 r2 ASR 4
};
const byte kInstruction_mov_cs_r6_r0_LSR_24[] = {
  0x28, 0xbf, 0x06, 0x0e // It cs; mov cs r6 r0 LSR 24
};
const byte kInstruction_mov_vc_r3_r0_LSR_25[] = {
  0x78, 0xbf, 0x43, 0x0e // It vc; mov vc r3 r0 LSR 25
};
const byte kInstruction_mov_vc_r6_r6_ASR_4[] = {
  0x78, 0xbf, 0x36, 0x11 // It vc; mov vc r6 r6 ASR 4
};
const byte kInstruction_mov_vc_r1_r3_LSR_15[] = {
  0x78, 0xbf, 0xd9, 0x0b // It vc; mov vc r1 r3 LSR 15
};
const byte kInstruction_mov_cc_r4_r2_ASR_26[] = {
  0x38, 0xbf, 0x94, 0x16 // It cc; mov cc r4 r2 ASR 26
};
const byte kInstruction_mov_pl_r2_r2_LSR_10[] = {
  0x58, 0xbf, 0x92, 0x0a // It pl; mov pl r2 r2 LSR 10
};
const byte kInstruction_mov_pl_r3_r0_LSR_27[] = {
  0x58, 0xbf, 0xc3, 0x0e // It pl; mov pl r3 r0 LSR 27
};
const byte kInstruction_mov_pl_r7_r7_LSR_21[] = {
  0x58, 0xbf, 0x7f, 0x0d // It pl; mov pl r7 r7 LSR 21
};
const byte kInstruction_mov_le_r3_r3_LSR_31[] = {
  0xd8, 0xbf, 0xdb, 0x0f // It le; mov le r3 r3 LSR 31
};
const byte kInstruction_mov_ge_r2_r2_LSR_10[] = {
  0xa8, 0xbf, 0x92, 0x0a // It ge; mov ge r2 r2 LSR 10
};
const byte kInstruction_mov_le_r2_r1_LSR_20[] = {
  0xd8, 0xbf, 0x0a, 0x0d // It le; mov le r2 r1 LSR 20
};
const byte kInstruction_mov_eq_r3_r3_LSR_4[] = {
  0x08, 0xbf, 0x1b, 0x09 // It eq; mov eq r3 r3 LSR 4
};
const byte kInstruction_mov_mi_r3_r6_ASR_7[] = {
  0x48, 0xbf, 0xf3, 0x11 // It mi; mov mi r3 r6 ASR 7
};
const byte kInstruction_mov_hi_r2_r6_ASR_29[] = {
  0x88, 0xbf, 0x72, 0x17 // It hi; mov hi r2 r6 ASR 29
};
const byte kInstruction_mov_pl_r2_r0_LSR_14[] = {
  0x58, 0xbf, 0x82, 0x0b // It pl; mov pl r2 r0 LSR 14
};
const byte kInstruction_mov_gt_r0_r7_ASR_26[] = {
  0xc8, 0xbf, 0xb8, 0x16 // It gt; mov gt r0 r7 ASR 26
};
const byte kInstruction_mov_lt_r1_r6_LSR_20[] = {
  0xb8, 0xbf, 0x31, 0x0d // It lt; mov lt r1 r6 LSR 20
};
const byte kInstruction_mov_le_r7_r1_ASR_20[] = {
  0xd8, 0xbf, 0x0f, 0x15 // It le; mov le r7 r1 ASR 20
};
const byte kInstruction_mov_mi_r5_r5_LSR_7[] = {
  0x48, 0xbf, 0xed, 0x09 // It mi; mov mi r5 r5 LSR 7
};
const byte kInstruction_mov_cc_r2_r3_LSR_23[] = {
  0x38, 0xbf, 0xda, 0x0d // It cc; mov cc r2 r3 LSR 23
};
const byte kInstruction_mov_gt_r4_r2_LSR_4[] = {
  0xc8, 0xbf, 0x14, 0x09 // It gt; mov gt r4 r2 LSR 4
};
const byte kInstruction_mov_vc_r3_r0_LSR_32[] = {
  0x78, 0xbf, 0x03, 0x08 // It vc; mov vc r3 r0 LSR 32
};
const byte kInstruction_mov_mi_r4_r0_LSR_15[] = {
  0x48, 0xbf, 0xc4, 0x0b // It mi; mov mi r4 r0 LSR 15
};
const byte kInstruction_mov_pl_r4_r2_ASR_19[] = {
  0x58, 0xbf, 0xd4, 0x14 // It pl; mov pl r4 r2 ASR 19
};
const byte kInstruction_mov_ge_r3_r3_ASR_3[] = {
  0xa8, 0xbf, 0xdb, 0x10 // It ge; mov ge r3 r3 ASR 3
};
const byte kInstruction_mov_cc_r4_r1_ASR_11[] = {
  0x38, 0xbf, 0xcc, 0x12 // It cc; mov cc r4 r1 ASR 11
};
const byte kInstruction_mov_ne_r4_r1_LSR_14[] = {
  0x18, 0xbf, 0x8c, 0x0b // It ne; mov ne r4 r1 LSR 14
};
const byte kInstruction_mov_hi_r4_r7_ASR_29[] = {
  0x88, 0xbf, 0x7c, 0x17 // It hi; mov hi r4 r7 ASR 29
};
const byte kInstruction_mov_ls_r0_r2_LSR_6[] = {
  0x98, 0xbf, 0x90, 0x09 // It ls; mov ls r0 r2 LSR 6
};
const byte kInstruction_mov_hi_r3_r0_LSR_18[] = {
  0x88, 0xbf, 0x83, 0x0c // It hi; mov hi r3 r0 LSR 18
};
const byte kInstruction_mov_ge_r2_r5_ASR_27[] = {
  0xa8, 0xbf, 0xea, 0x16 // It ge; mov ge r2 r5 ASR 27
};
const byte kInstruction_mov_vs_r6_r3_ASR_10[] = {
  0x68, 0xbf, 0x9e, 0x12 // It vs; mov vs r6 r3 ASR 10
};
const byte kInstruction_mov_cs_r7_r2_LSR_19[] = {
  0x28, 0xbf, 0xd7, 0x0c // It cs; mov cs r7 r2 LSR 19
};
const byte kInstruction_mov_vs_r2_r6_ASR_4[] = {
  0x68, 0xbf, 0x32, 0x11 // It vs; mov vs r2 r6 ASR 4
};
const byte kInstruction_mov_vs_r3_r2_ASR_26[] = {
  0x68, 0xbf, 0x93, 0x16 // It vs; mov vs r3 r2 ASR 26
};
const byte kInstruction_mov_gt_r3_r3_LSR_14[] = {
  0xc8, 0xbf, 0x9b, 0x0b // It gt; mov gt r3 r3 LSR 14
};
const byte kInstruction_mov_mi_r1_r3_ASR_20[] = {
  0x48, 0xbf, 0x19, 0x15 // It mi; mov mi r1 r3 ASR 20
};
const byte kInstruction_mov_eq_r2_r0_LSR_3[] = {
  0x08, 0xbf, 0xc2, 0x08 // It eq; mov eq r2 r0 LSR 3
};
const byte kInstruction_mov_lt_r4_r3_LSR_14[] = {
  0xb8, 0xbf, 0x9c, 0x0b // It lt; mov lt r4 r3 LSR 14
};
const byte kInstruction_mov_vs_r2_r7_ASR_13[] = {
  0x68, 0xbf, 0x7a, 0x13 // It vs; mov vs r2 r7 ASR 13
};
const byte kInstruction_mov_ls_r4_r1_ASR_31[] = {
  0x98, 0xbf, 0xcc, 0x17 // It ls; mov ls r4 r1 ASR 31
};
const byte kInstruction_mov_le_r4_r3_ASR_17[] = {
  0xd8, 0xbf, 0x5c, 0x14 // It le; mov le r4 r3 ASR 17
};
const byte kInstruction_mov_mi_r7_r0_LSR_14[] = {
  0x48, 0xbf, 0x87, 0x0b // It mi; mov mi r7 r0 LSR 14
};
const byte kInstruction_mov_ne_r5_r6_LSR_6[] = {
  0x18, 0xbf, 0xb5, 0x09 // It ne; mov ne r5 r6 LSR 6
};
const byte kInstruction_mov_lt_r5_r2_LSR_6[] = {
  0xb8, 0xbf, 0x95, 0x09 // It lt; mov lt r5 r2 LSR 6
};
const byte kInstruction_mov_gt_r6_r1_ASR_30[] = {
  0xc8, 0xbf, 0x8e, 0x17 // It gt; mov gt r6 r1 ASR 30
};
const byte kInstruction_mov_ne_r7_r7_ASR_30[] = {
  0x18, 0xbf, 0xbf, 0x17 // It ne; mov ne r7 r7 ASR 30
};
const byte kInstruction_mov_ls_r5_r1_ASR_25[] = {
  0x98, 0xbf, 0x4d, 0x16 // It ls; mov ls r5 r1 ASR 25
};
const byte kInstruction_mov_lt_r3_r2_LSR_29[] = {
  0xb8, 0xbf, 0x53, 0x0f // It lt; mov lt r3 r2 LSR 29
};
const byte kInstruction_mov_le_r6_r1_LSR_6[] = {
  0xd8, 0xbf, 0x8e, 0x09 // It le; mov le r6 r1 LSR 6
};
const byte kInstruction_mov_gt_r7_r6_ASR_12[] = {
  0xc8, 0xbf, 0x37, 0x13 // It gt; mov gt r7 r6 ASR 12
};
const byte kInstruction_mov_ls_r6_r2_ASR_10[] = {
  0x98, 0xbf, 0x96, 0x12 // It ls; mov ls r6 r2 ASR 10
};
const byte kInstruction_mov_ne_r7_r7_LSR_6[] = {
  0x18, 0xbf, 0xbf, 0x09 // It ne; mov ne r7 r7 LSR 6
};
const byte kInstruction_mov_mi_r0_r3_ASR_5[] = {
  0x48, 0xbf, 0x58, 0x11 // It mi; mov mi r0 r3 ASR 5
};
const byte kInstruction_mov_ne_r0_r4_LSR_3[] = {
  0x18, 0xbf, 0xe0, 0x08 // It ne; mov ne r0 r4 LSR 3
};
const byte kInstruction_mov_ge_r3_r4_ASR_16[] = {
  0xa8, 0xbf, 0x23, 0x14 // It ge; mov ge r3 r4 ASR 16
};
const byte kInstruction_mov_ls_r4_r5_ASR_19[] = {
  0x98, 0xbf, 0xec, 0x14 // It ls; mov ls r4 r5 ASR 19
};
const byte kInstruction_mov_eq_r1_r7_ASR_21[] = {
  0x08, 0xbf, 0x79, 0x15 // It eq; mov eq r1 r7 ASR 21
};
const byte kInstruction_mov_hi_r6_r4_ASR_30[] = {
  0x88, 0xbf, 0xa6, 0x17 // It hi; mov hi r6 r4 ASR 30
};
const byte kInstruction_mov_eq_r7_r1_LSR_3[] = {
  0x08, 0xbf, 0xcf, 0x08 // It eq; mov eq r7 r1 LSR 3
};
const byte kInstruction_mov_pl_r6_r2_ASR_12[] = {
  0x58, 0xbf, 0x16, 0x13 // It pl; mov pl r6 r2 ASR 12
};
const byte kInstruction_mov_eq_r6_r3_LSR_28[] = {
  0x08, 0xbf, 0x1e, 0x0f // It eq; mov eq r6 r3 LSR 28
};
const byte kInstruction_mov_cc_r6_r6_LSR_5[] = {
  0x38, 0xbf, 0x76, 0x09 // It cc; mov cc r6 r6 LSR 5
};
const byte kInstruction_mov_le_r2_r4_ASR_3[] = {
  0xd8, 0xbf, 0xe2, 0x10 // It le; mov le r2 r4 ASR 3
};
const byte kInstruction_mov_vc_r7_r4_LSR_30[] = {
  0x78, 0xbf, 0xa7, 0x0f // It vc; mov vc r7 r4 LSR 30
};
const byte kInstruction_mov_ge_r0_r0_LSR_25[] = {
  0xa8, 0xbf, 0x40, 0x0e // It ge; mov ge r0 r0 LSR 25
};
const byte kInstruction_mov_ls_r0_r2_ASR_27[] = {
  0x98, 0xbf, 0xd0, 0x16 // It ls; mov ls r0 r2 ASR 27
};
const byte kInstruction_mov_cc_r5_r6_LSR_22[] = {
  0x38, 0xbf, 0xb5, 0x0d // It cc; mov cc r5 r6 LSR 22
};
const byte kInstruction_mov_lt_r0_r4_LSR_17[] = {
  0xb8, 0xbf, 0x60, 0x0c // It lt; mov lt r0 r4 LSR 17
};
const byte kInstruction_mov_le_r0_r4_ASR_1[] = {
  0xd8, 0xbf, 0x60, 0x10 // It le; mov le r0 r4 ASR 1
};
const byte kInstruction_mov_hi_r5_r5_ASR_6[] = {
  0x88, 0xbf, 0xad, 0x11 // It hi; mov hi r5 r5 ASR 6
};
const byte kInstruction_mov_vc_r7_r0_LSR_16[] = {
  0x78, 0xbf, 0x07, 0x0c // It vc; mov vc r7 r0 LSR 16
};
const byte kInstruction_mov_ne_r6_r1_ASR_16[] = {
  0x18, 0xbf, 0x0e, 0x14 // It ne; mov ne r6 r1 ASR 16
};
const byte kInstruction_mov_vs_r7_r0_LSR_31[] = {
  0x68, 0xbf, 0xc7, 0x0f // It vs; mov vs r7 r0 LSR 31
};
const byte kInstruction_mov_ne_r3_r2_ASR_18[] = {
  0x18, 0xbf, 0x93, 0x14 // It ne; mov ne r3 r2 ASR 18
};
const byte kInstruction_mov_vs_r2_r2_LSR_18[] = {
  0x68, 0xbf, 0x92, 0x0c // It vs; mov vs r2 r2 LSR 18
};
const byte kInstruction_mov_mi_r6_r2_ASR_25[] = {
  0x48, 0xbf, 0x56, 0x16 // It mi; mov mi r6 r2 ASR 25
};
const byte kInstruction_mov_hi_r7_r6_ASR_28[] = {
  0x88, 0xbf, 0x37, 0x17 // It hi; mov hi r7 r6 ASR 28
};
const byte kInstruction_mov_gt_r2_r1_ASR_3[] = {
  0xc8, 0xbf, 0xca, 0x10 // It gt; mov gt r2 r1 ASR 3
};
const byte kInstruction_mov_ne_r0_r1_ASR_31[] = {
  0x18, 0xbf, 0xc8, 0x17 // It ne; mov ne r0 r1 ASR 31
};
const byte kInstruction_mov_hi_r2_r7_ASR_24[] = {
  0x88, 0xbf, 0x3a, 0x16 // It hi; mov hi r2 r7 ASR 24
};
const byte kInstruction_mov_hi_r2_r5_ASR_30[] = {
  0x88, 0xbf, 0xaa, 0x17 // It hi; mov hi r2 r5 ASR 30
};
const byte kInstruction_mov_gt_r3_r2_ASR_11[] = {
  0xc8, 0xbf, 0xd3, 0x12 // It gt; mov gt r3 r2 ASR 11
};
const byte kInstruction_mov_ge_r4_r0_ASR_3[] = {
  0xa8, 0xbf, 0xc4, 0x10 // It ge; mov ge r4 r0 ASR 3
};
const byte kInstruction_mov_mi_r0_r4_LSR_19[] = {
  0x48, 0xbf, 0xe0, 0x0c // It mi; mov mi r0 r4 LSR 19
};
const byte kInstruction_mov_gt_r0_r5_ASR_30[] = {
  0xc8, 0xbf, 0xa8, 0x17 // It gt; mov gt r0 r5 ASR 30
};
const byte kInstruction_mov_vs_r0_r3_LSR_16[] = {
  0x68, 0xbf, 0x18, 0x0c // It vs; mov vs r0 r3 LSR 16
};
const byte kInstruction_mov_ls_r4_r1_LSR_3[] = {
  0x98, 0xbf, 0xcc, 0x08 // It ls; mov ls r4 r1 LSR 3
};
const byte kInstruction_mov_vc_r4_r3_ASR_17[] = {
  0x78, 0xbf, 0x5c, 0x14 // It vc; mov vc r4 r3 ASR 17
};
const byte kInstruction_mov_gt_r0_r1_LSR_5[] = {
  0xc8, 0xbf, 0x48, 0x09 // It gt; mov gt r0 r1 LSR 5
};
const byte kInstruction_mov_ls_r1_r4_ASR_6[] = {
  0x98, 0xbf, 0xa1, 0x11 // It ls; mov ls r1 r4 ASR 6
};
const byte kInstruction_mov_ge_r1_r1_ASR_23[] = {
  0xa8, 0xbf, 0xc9, 0x15 // It ge; mov ge r1 r1 ASR 23
};
const byte kInstruction_mov_hi_r1_r3_ASR_28[] = {
  0x88, 0xbf, 0x19, 0x17 // It hi; mov hi r1 r3 ASR 28
};
const byte kInstruction_mov_vc_r1_r1_ASR_11[] = {
  0x78, 0xbf, 0xc9, 0x12 // It vc; mov vc r1 r1 ASR 11
};
const byte kInstruction_mov_le_r0_r4_ASR_24[] = {
  0xd8, 0xbf, 0x20, 0x16 // It le; mov le r0 r4 ASR 24
};
const byte kInstruction_mov_cc_r4_r7_LSR_4[] = {
  0x38, 0xbf, 0x3c, 0x09 // It cc; mov cc r4 r7 LSR 4
};
const byte kInstruction_mov_hi_r6_r2_LSR_7[] = {
  0x88, 0xbf, 0xd6, 0x09 // It hi; mov hi r6 r2 LSR 7
};
const byte kInstruction_mov_le_r1_r1_LSR_22[] = {
  0xd8, 0xbf, 0x89, 0x0d // It le; mov le r1 r1 LSR 22
};
const byte kInstruction_mov_le_r6_r4_LSR_6[] = {
  0xd8, 0xbf, 0xa6, 0x09 // It le; mov le r6 r4 LSR 6
};
const byte kInstruction_mov_le_r2_r5_ASR_11[] = {
  0xd8, 0xbf, 0xea, 0x12 // It le; mov le r2 r5 ASR 11
};
const byte kInstruction_mov_vc_r5_r1_ASR_2[] = {
  0x78, 0xbf, 0x8d, 0x10 // It vc; mov vc r5 r1 ASR 2
};
const byte kInstruction_mov_lt_r7_r4_LSR_31[] = {
  0xb8, 0xbf, 0xe7, 0x0f // It lt; mov lt r7 r4 LSR 31
};
const byte kInstruction_mov_hi_r6_r1_LSR_28[] = {
  0x88, 0xbf, 0x0e, 0x0f // It hi; mov hi r6 r1 LSR 28
};
const byte kInstruction_mov_ne_r7_r7_LSR_24[] = {
  0x18, 0xbf, 0x3f, 0x0e // It ne; mov ne r7 r7 LSR 24
};
const byte kInstruction_mov_ge_r7_r6_LSR_32[] = {
  0xa8, 0xbf, 0x37, 0x08 // It ge; mov ge r7 r6 LSR 32
};
const byte kInstruction_mov_hi_r6_r4_LSR_25[] = {
  0x88, 0xbf, 0x66, 0x0e // It hi; mov hi r6 r4 LSR 25
};
const byte kInstruction_mov_pl_r2_r6_ASR_3[] = {
  0x58, 0xbf, 0xf2, 0x10 // It pl; mov pl r2 r6 ASR 3
};
const byte kInstruction_mov_ls_r5_r1_LSR_20[] = {
  0x98, 0xbf, 0x0d, 0x0d // It ls; mov ls r5 r1 LSR 20
};
const byte kInstruction_mov_hi_r1_r1_LSR_10[] = {
  0x88, 0xbf, 0x89, 0x0a // It hi; mov hi r1 r1 LSR 10
};
const byte kInstruction_mov_lt_r6_r1_ASR_29[] = {
  0xb8, 0xbf, 0x4e, 0x17 // It lt; mov lt r6 r1 ASR 29
};
const byte kInstruction_mov_mi_r7_r5_ASR_14[] = {
  0x48, 0xbf, 0xaf, 0x13 // It mi; mov mi r7 r5 ASR 14
};
const byte kInstruction_mov_le_r1_r0_ASR_5[] = {
  0xd8, 0xbf, 0x41, 0x11 // It le; mov le r1 r0 ASR 5
};
const byte kInstruction_mov_gt_r7_r2_ASR_18[] = {
  0xc8, 0xbf, 0x97, 0x14 // It gt; mov gt r7 r2 ASR 18
};
const byte kInstruction_mov_pl_r5_r4_LSR_12[] = {
  0x58, 0xbf, 0x25, 0x0b // It pl; mov pl r5 r4 LSR 12
};
const byte kInstruction_mov_mi_r1_r3_ASR_21[] = {
  0x48, 0xbf, 0x59, 0x15 // It mi; mov mi r1 r3 ASR 21
};
const byte kInstruction_mov_mi_r7_r7_LSR_13[] = {
  0x48, 0xbf, 0x7f, 0x0b // It mi; mov mi r7 r7 LSR 13
};
const byte kInstruction_mov_gt_r1_r4_LSR_7[] = {
  0xc8, 0xbf, 0xe1, 0x09 // It gt; mov gt r1 r4 LSR 7
};
const byte kInstruction_mov_vc_r5_r5_ASR_28[] = {
  0x78, 0xbf, 0x2d, 0x17 // It vc; mov vc r5 r5 ASR 28
};
const byte kInstruction_mov_mi_r3_r3_LSR_24[] = {
  0x48, 0xbf, 0x1b, 0x0e // It mi; mov mi r3 r3 LSR 24
};
const byte kInstruction_mov_ls_r4_r7_LSR_32[] = {
  0x98, 0xbf, 0x3c, 0x08 // It ls; mov ls r4 r7 LSR 32
};
const byte kInstruction_mov_mi_r1_r4_LSR_18[] = {
  0x48, 0xbf, 0xa1, 0x0c // It mi; mov mi r1 r4 LSR 18
};
const byte kInstruction_mov_le_r3_r6_LSR_10[] = {
  0xd8, 0xbf, 0xb3, 0x0a // It le; mov le r3 r6 LSR 10
};
const byte kInstruction_mov_gt_r3_r3_ASR_17[] = {
  0xc8, 0xbf, 0x5b, 0x14 // It gt; mov gt r3 r3 ASR 17
};
const byte kInstruction_mov_ls_r1_r5_LSR_25[] = {
  0x98, 0xbf, 0x69, 0x0e // It ls; mov ls r1 r5 LSR 25
};
const byte kInstruction_mov_vs_r1_r0_ASR_11[] = {
  0x68, 0xbf, 0xc1, 0x12 // It vs; mov vs r1 r0 ASR 11
};
const byte kInstruction_mov_cs_r0_r6_ASR_17[] = {
  0x28, 0xbf, 0x70, 0x14 // It cs; mov cs r0 r6 ASR 17
};
const byte kInstruction_mov_cs_r0_r6_LSR_14[] = {
  0x28, 0xbf, 0xb0, 0x0b // It cs; mov cs r0 r6 LSR 14
};
const byte kInstruction_mov_lt_r4_r6_LSR_13[] = {
  0xb8, 0xbf, 0x74, 0x0b // It lt; mov lt r4 r6 LSR 13
};
const byte kInstruction_mov_vs_r6_r4_ASR_23[] = {
  0x68, 0xbf, 0xe6, 0x15 // It vs; mov vs r6 r4 ASR 23
};
const byte kInstruction_mov_cc_r4_r4_ASR_12[] = {
  0x38, 0xbf, 0x24, 0x13 // It cc; mov cc r4 r4 ASR 12
};
const byte kInstruction_mov_lt_r1_r6_LSR_28[] = {
  0xb8, 0xbf, 0x31, 0x0f // It lt; mov lt r1 r6 LSR 28
};
const byte kInstruction_mov_cc_r4_r2_ASR_2[] = {
  0x38, 0xbf, 0x94, 0x10 // It cc; mov cc r4 r2 ASR 2
};
const byte kInstruction_mov_ls_r2_r0_ASR_27[] = {
  0x98, 0xbf, 0xc2, 0x16 // It ls; mov ls r2 r0 ASR 27
};
const byte kInstruction_mov_le_r6_r3_LSR_32[] = {
  0xd8, 0xbf, 0x1e, 0x08 // It le; mov le r6 r3 LSR 32
};
const byte kInstruction_mov_cs_r6_r7_ASR_10[] = {
  0x28, 0xbf, 0xbe, 0x12 // It cs; mov cs r6 r7 ASR 10
};
const byte kInstruction_mov_vs_r0_r1_ASR_31[] = {
  0x68, 0xbf, 0xc8, 0x17 // It vs; mov vs r0 r1 ASR 31
};
const byte kInstruction_mov_vc_r2_r3_ASR_2[] = {
  0x78, 0xbf, 0x9a, 0x10 // It vc; mov vc r2 r3 ASR 2
};
const byte kInstruction_mov_ge_r1_r7_ASR_24[] = {
  0xa8, 0xbf, 0x39, 0x16 // It ge; mov ge r1 r7 ASR 24
};
const byte kInstruction_mov_eq_r3_r2_LSR_21[] = {
  0x08, 0xbf, 0x53, 0x0d // It eq; mov eq r3 r2 LSR 21
};
const byte kInstruction_mov_ge_r4_r3_ASR_22[] = {
  0xa8, 0xbf, 0x9c, 0x15 // It ge; mov ge r4 r3 ASR 22
};
const byte kInstruction_mov_hi_r2_r0_LSR_1[] = {
  0x88, 0xbf, 0x42, 0x08 // It hi; mov hi r2 r0 LSR 1
};
const byte kInstruction_mov_vs_r2_r4_LSR_9[] = {
  0x68, 0xbf, 0x62, 0x0a // It vs; mov vs r2 r4 LSR 9
};
const byte kInstruction_mov_ls_r5_r3_LSR_20[] = {
  0x98, 0xbf, 0x1d, 0x0d // It ls; mov ls r5 r3 LSR 20
};
const byte kInstruction_mov_cs_r4_r0_ASR_5[] = {
  0x28, 0xbf, 0x44, 0x11 // It cs; mov cs r4 r0 ASR 5
};
const byte kInstruction_mov_lt_r6_r2_LSR_5[] = {
  0xb8, 0xbf, 0x56, 0x09 // It lt; mov lt r6 r2 LSR 5
};
const byte kInstruction_mov_ls_r4_r6_LSR_24[] = {
  0x98, 0xbf, 0x34, 0x0e // It ls; mov ls r4 r6 LSR 24
};
const byte kInstruction_mov_le_r6_r3_LSR_26[] = {
  0xd8, 0xbf, 0x9e, 0x0e // It le; mov le r6 r3 LSR 26
};
const byte kInstruction_mov_ne_r4_r5_ASR_27[] = {
  0x18, 0xbf, 0xec, 0x16 // It ne; mov ne r4 r5 ASR 27
};
const byte kInstruction_mov_hi_r2_r1_LSR_19[] = {
  0x88, 0xbf, 0xca, 0x0c // It hi; mov hi r2 r1 LSR 19
};
const byte kInstruction_mov_mi_r2_r3_LSR_17[] = {
  0x48, 0xbf, 0x5a, 0x0c // It mi; mov mi r2 r3 LSR 17
};
const byte kInstruction_mov_eq_r6_r4_LSR_3[] = {
  0x08, 0xbf, 0xe6, 0x08 // It eq; mov eq r6 r4 LSR 3
};
const byte kInstruction_mov_ne_r3_r1_LSR_5[] = {
  0x18, 0xbf, 0x4b, 0x09 // It ne; mov ne r3 r1 LSR 5
};
const byte kInstruction_mov_vs_r1_r4_ASR_4[] = {
  0x68, 0xbf, 0x21, 0x11 // It vs; mov vs r1 r4 ASR 4
};
const byte kInstruction_mov_ls_r0_r3_LSR_22[] = {
  0x98, 0xbf, 0x98, 0x0d // It ls; mov ls r0 r3 LSR 22
};
const byte kInstruction_mov_mi_r6_r4_LSR_1[] = {
  0x48, 0xbf, 0x66, 0x08 // It mi; mov mi r6 r4 LSR 1
};
const byte kInstruction_mov_hi_r5_r4_LSR_12[] = {
  0x88, 0xbf, 0x25, 0x0b // It hi; mov hi r5 r4 LSR 12
};
const byte kInstruction_mov_le_r0_r3_LSR_3[] = {
  0xd8, 0xbf, 0xd8, 0x08 // It le; mov le r0 r3 LSR 3
};
const byte kInstruction_mov_pl_r1_r6_LSR_30[] = {
  0x58, 0xbf, 0xb1, 0x0f // It pl; mov pl r1 r6 LSR 30
};
const byte kInstruction_mov_ne_r7_r2_ASR_31[] = {
  0x18, 0xbf, 0xd7, 0x17 // It ne; mov ne r7 r2 ASR 31
};
const byte kInstruction_mov_ge_r6_r2_ASR_11[] = {
  0xa8, 0xbf, 0xd6, 0x12 // It ge; mov ge r6 r2 ASR 11
};
const byte kInstruction_mov_pl_r0_r1_LSR_28[] = {
  0x58, 0xbf, 0x08, 0x0f // It pl; mov pl r0 r1 LSR 28
};
const byte kInstruction_mov_lt_r6_r4_LSR_23[] = {
  0xb8, 0xbf, 0xe6, 0x0d // It lt; mov lt r6 r4 LSR 23
};
const byte kInstruction_mov_mi_r2_r4_LSR_1[] = {
  0x48, 0xbf, 0x62, 0x08 // It mi; mov mi r2 r4 LSR 1
};
const byte kInstruction_mov_mi_r7_r3_ASR_18[] = {
  0x48, 0xbf, 0x9f, 0x14 // It mi; mov mi r7 r3 ASR 18
};
const byte kInstruction_mov_ls_r4_r1_LSR_24[] = {
  0x98, 0xbf, 0x0c, 0x0e // It ls; mov ls r4 r1 LSR 24
};
const byte kInstruction_mov_ne_r4_r4_ASR_7[] = {
  0x18, 0xbf, 0xe4, 0x11 // It ne; mov ne r4 r4 ASR 7
};
const byte kInstruction_mov_lt_r4_r4_ASR_23[] = {
  0xb8, 0xbf, 0xe4, 0x15 // It lt; mov lt r4 r4 ASR 23
};
const byte kInstruction_mov_vs_r7_r2_ASR_24[] = {
  0x68, 0xbf, 0x17, 0x16 // It vs; mov vs r7 r2 ASR 24
};
const byte kInstruction_mov_cs_r2_r4_ASR_24[] = {
  0x28, 0xbf, 0x22, 0x16 // It cs; mov cs r2 r4 ASR 24
};
const byte kInstruction_mov_ge_r6_r0_LSR_9[] = {
  0xa8, 0xbf, 0x46, 0x0a // It ge; mov ge r6 r0 LSR 9
};
const byte kInstruction_mov_mi_r2_r1_ASR_10[] = {
  0x48, 0xbf, 0x8a, 0x12 // It mi; mov mi r2 r1 ASR 10
};
const byte kInstruction_mov_mi_r6_r3_ASR_13[] = {
  0x48, 0xbf, 0x5e, 0x13 // It mi; mov mi r6 r3 ASR 13
};
const byte kInstruction_mov_vc_r4_r6_ASR_28[] = {
  0x78, 0xbf, 0x34, 0x17 // It vc; mov vc r4 r6 ASR 28
};
const byte kInstruction_mov_pl_r6_r7_ASR_1[] = {
  0x58, 0xbf, 0x7e, 0x10 // It pl; mov pl r6 r7 ASR 1
};
const byte kInstruction_mov_gt_r1_r2_ASR_18[] = {
  0xc8, 0xbf, 0x91, 0x14 // It gt; mov gt r1 r2 ASR 18
};
const byte kInstruction_mov_hi_r6_r2_LSR_32[] = {
  0x88, 0xbf, 0x16, 0x08 // It hi; mov hi r6 r2 LSR 32
};
const byte kInstruction_mov_eq_r3_r0_ASR_10[] = {
  0x08, 0xbf, 0x83, 0x12 // It eq; mov eq r3 r0 ASR 10
};
const byte kInstruction_mov_mi_r0_r3_ASR_8[] = {
  0x48, 0xbf, 0x18, 0x12 // It mi; mov mi r0 r3 ASR 8
};
const byte kInstruction_mov_pl_r6_r0_ASR_27[] = {
  0x58, 0xbf, 0xc6, 0x16 // It pl; mov pl r6 r0 ASR 27
};
const byte kInstruction_mov_lt_r6_r4_ASR_28[] = {
  0xb8, 0xbf, 0x26, 0x17 // It lt; mov lt r6 r4 ASR 28
};
const byte kInstruction_mov_ne_r6_r3_ASR_25[] = {
  0x18, 0xbf, 0x5e, 0x16 // It ne; mov ne r6 r3 ASR 25
};
const byte kInstruction_mov_lt_r1_r1_LSR_16[] = {
  0xb8, 0xbf, 0x09, 0x0c // It lt; mov lt r1 r1 LSR 16
};
const byte kInstruction_mov_vs_r4_r3_ASR_18[] = {
  0x68, 0xbf, 0x9c, 0x14 // It vs; mov vs r4 r3 ASR 18
};
const byte kInstruction_mov_vs_r3_r5_LSR_16[] = {
  0x68, 0xbf, 0x2b, 0x0c // It vs; mov vs r3 r5 LSR 16
};
const byte kInstruction_mov_le_r6_r1_LSR_31[] = {
  0xd8, 0xbf, 0xce, 0x0f // It le; mov le r6 r1 LSR 31
};
const byte kInstruction_mov_ls_r6_r3_LSR_14[] = {
  0x98, 0xbf, 0x9e, 0x0b // It ls; mov ls r6 r3 LSR 14
};
const byte kInstruction_mov_pl_r3_r6_ASR_17[] = {
  0x58, 0xbf, 0x73, 0x14 // It pl; mov pl r3 r6 ASR 17
};
const byte kInstruction_mov_vc_r7_r7_ASR_1[] = {
  0x78, 0xbf, 0x7f, 0x10 // It vc; mov vc r7 r7 ASR 1
};
const byte kInstruction_mov_cc_r2_r0_ASR_17[] = {
  0x38, 0xbf, 0x42, 0x14 // It cc; mov cc r2 r0 ASR 17
};
const byte kInstruction_mov_le_r7_r1_LSR_32[] = {
  0xd8, 0xbf, 0x0f, 0x08 // It le; mov le r7 r1 LSR 32
};
const byte kInstruction_mov_eq_r1_r3_ASR_8[] = {
  0x08, 0xbf, 0x19, 0x12 // It eq; mov eq r1 r3 ASR 8
};
const byte kInstruction_mov_vc_r4_r5_LSR_18[] = {
  0x78, 0xbf, 0xac, 0x0c // It vc; mov vc r4 r5 LSR 18
};
const byte kInstruction_mov_hi_r0_r2_ASR_32[] = {
  0x88, 0xbf, 0x10, 0x10 // It hi; mov hi r0 r2 ASR 32
};
const byte kInstruction_mov_le_r4_r6_ASR_4[] = {
  0xd8, 0xbf, 0x34, 0x11 // It le; mov le r4 r6 ASR 4
};
const byte kInstruction_mov_mi_r5_r5_ASR_7[] = {
  0x48, 0xbf, 0xed, 0x11 // It mi; mov mi r5 r5 ASR 7
};
const byte kInstruction_mov_eq_r6_r5_LSR_24[] = {
  0x08, 0xbf, 0x2e, 0x0e // It eq; mov eq r6 r5 LSR 24
};
const byte kInstruction_mov_pl_r5_r5_ASR_9[] = {
  0x58, 0xbf, 0x6d, 0x12 // It pl; mov pl r5 r5 ASR 9
};
const byte kInstruction_mov_ne_r6_r2_ASR_24[] = {
  0x18, 0xbf, 0x16, 0x16 // It ne; mov ne r6 r2 ASR 24
};
const byte kInstruction_mov_eq_r3_r7_ASR_3[] = {
  0x08, 0xbf, 0xfb, 0x10 // It eq; mov eq r3 r7 ASR 3
};
const byte kInstruction_mov_lt_r6_r0_LSR_25[] = {
  0xb8, 0xbf, 0x46, 0x0e // It lt; mov lt r6 r0 LSR 25
};
const byte kInstruction_mov_ls_r5_r5_ASR_8[] = {
  0x98, 0xbf, 0x2d, 0x12 // It ls; mov ls r5 r5 ASR 8
};
const byte kInstruction_mov_hi_r5_r6_ASR_17[] = {
  0x88, 0xbf, 0x75, 0x14 // It hi; mov hi r5 r6 ASR 17
};
const byte kInstruction_mov_ne_r4_r0_ASR_18[] = {
  0x18, 0xbf, 0x84, 0x14 // It ne; mov ne r4 r0 ASR 18
};
const byte kInstruction_mov_mi_r2_r4_LSR_30[] = {
  0x48, 0xbf, 0xa2, 0x0f // It mi; mov mi r2 r4 LSR 30
};
const byte kInstruction_mov_cc_r1_r6_ASR_5[] = {
  0x38, 0xbf, 0x71, 0x11 // It cc; mov cc r1 r6 ASR 5
};
const byte kInstruction_mov_hi_r7_r2_LSR_15[] = {
  0x88, 0xbf, 0xd7, 0x0b // It hi; mov hi r7 r2 LSR 15
};
const byte kInstruction_mov_cc_r7_r7_ASR_29[] = {
  0x38, 0xbf, 0x7f, 0x17 // It cc; mov cc r7 r7 ASR 29
};
const byte kInstruction_mov_eq_r7_r4_ASR_22[] = {
  0x08, 0xbf, 0xa7, 0x15 // It eq; mov eq r7 r4 ASR 22
};
const byte kInstruction_mov_mi_r3_r3_ASR_2[] = {
  0x48, 0xbf, 0x9b, 0x10 // It mi; mov mi r3 r3 ASR 2
};
const byte kInstruction_mov_le_r2_r5_LSR_14[] = {
  0xd8, 0xbf, 0xaa, 0x0b // It le; mov le r2 r5 LSR 14
};
const byte kInstruction_mov_pl_r6_r5_ASR_12[] = {
  0x58, 0xbf, 0x2e, 0x13 // It pl; mov pl r6 r5 ASR 12
};
const byte kInstruction_mov_ne_r5_r6_LSR_11[] = {
  0x18, 0xbf, 0xf5, 0x0a // It ne; mov ne r5 r6 LSR 11
};
const byte kInstruction_mov_cs_r0_r1_ASR_29[] = {
  0x28, 0xbf, 0x48, 0x17 // It cs; mov cs r0 r1 ASR 29
};
const byte kInstruction_mov_cc_r3_r6_LSR_5[] = {
  0x38, 0xbf, 0x73, 0x09 // It cc; mov cc r3 r6 LSR 5
};
const byte kInstruction_mov_ge_r5_r4_LSR_10[] = {
  0xa8, 0xbf, 0xa5, 0x0a // It ge; mov ge r5 r4 LSR 10
};
const byte kInstruction_mov_vs_r7_r5_ASR_9[] = {
  0x68, 0xbf, 0x6f, 0x12 // It vs; mov vs r7 r5 ASR 9
};
const byte kInstruction_mov_ge_r6_r4_LSR_22[] = {
  0xa8, 0xbf, 0xa6, 0x0d // It ge; mov ge r6 r4 LSR 22
};
const byte kInstruction_mov_vs_r0_r7_ASR_20[] = {
  0x68, 0xbf, 0x38, 0x15 // It vs; mov vs r0 r7 ASR 20
};
const byte kInstruction_mov_ls_r1_r5_LSR_21[] = {
  0x98, 0xbf, 0x69, 0x0d // It ls; mov ls r1 r5 LSR 21
};
const byte kInstruction_mov_cc_r3_r3_ASR_16[] = {
  0x38, 0xbf, 0x1b, 0x14 // It cc; mov cc r3 r3 ASR 16
};
const byte kInstruction_mov_hi_r2_r3_ASR_30[] = {
  0x88, 0xbf, 0x9a, 0x17 // It hi; mov hi r2 r3 ASR 30
};
const byte kInstruction_mov_cs_r5_r3_LSR_12[] = {
  0x28, 0xbf, 0x1d, 0x0b // It cs; mov cs r5 r3 LSR 12
};
const byte kInstruction_mov_cc_r5_r5_ASR_24[] = {
  0x38, 0xbf, 0x2d, 0x16 // It cc; mov cc r5 r5 ASR 24
};
const byte kInstruction_mov_vc_r7_r0_ASR_18[] = {
  0x78, 0xbf, 0x87, 0x14 // It vc; mov vc r7 r0 ASR 18
};
const byte kInstruction_mov_mi_r4_r7_ASR_30[] = {
  0x48, 0xbf, 0xbc, 0x17 // It mi; mov mi r4 r7 ASR 30
};
const byte kInstruction_mov_vc_r6_r0_LSR_17[] = {
  0x78, 0xbf, 0x46, 0x0c // It vc; mov vc r6 r0 LSR 17
};
const byte kInstruction_mov_eq_r3_r3_ASR_2[] = {
  0x08, 0xbf, 0x9b, 0x10 // It eq; mov eq r3 r3 ASR 2
};
const byte kInstruction_mov_ne_r5_r2_LSR_31[] = {
  0x18, 0xbf, 0xd5, 0x0f // It ne; mov ne r5 r2 LSR 31
};
const byte kInstruction_mov_ne_r4_r2_ASR_6[] = {
  0x18, 0xbf, 0x94, 0x11 // It ne; mov ne r4 r2 ASR 6
};
const byte kInstruction_mov_eq_r3_r7_ASR_25[] = {
  0x08, 0xbf, 0x7b, 0x16 // It eq; mov eq r3 r7 ASR 25
};
const byte kInstruction_mov_pl_r1_r7_LSR_11[] = {
  0x58, 0xbf, 0xf9, 0x0a // It pl; mov pl r1 r7 LSR 11
};
const byte kInstruction_mov_lt_r4_r4_ASR_1[] = {
  0xb8, 0xbf, 0x64, 0x10 // It lt; mov lt r4 r4 ASR 1
};
const byte kInstruction_mov_vc_r7_r4_LSR_8[] = {
  0x78, 0xbf, 0x27, 0x0a // It vc; mov vc r7 r4 LSR 8
};
const byte kInstruction_mov_ls_r1_r4_ASR_4[] = {
  0x98, 0xbf, 0x21, 0x11 // It ls; mov ls r1 r4 ASR 4
};
const byte kInstruction_mov_cc_r2_r4_LSR_18[] = {
  0x38, 0xbf, 0xa2, 0x0c // It cc; mov cc r2 r4 LSR 18
};
const byte kInstruction_mov_gt_r0_r5_LSR_8[] = {
  0xc8, 0xbf, 0x28, 0x0a // It gt; mov gt r0 r5 LSR 8
};
const byte kInstruction_mov_lt_r4_r1_LSR_4[] = {
  0xb8, 0xbf, 0x0c, 0x09 // It lt; mov lt r4 r1 LSR 4
};
const byte kInstruction_mov_gt_r7_r7_ASR_12[] = {
  0xc8, 0xbf, 0x3f, 0x13 // It gt; mov gt r7 r7 ASR 12
};
const byte kInstruction_mov_vs_r0_r6_LSR_28[] = {
  0x68, 0xbf, 0x30, 0x0f // It vs; mov vs r0 r6 LSR 28
};
const byte kInstruction_mov_vs_r0_r5_LSR_25[] = {
  0x68, 0xbf, 0x68, 0x0e // It vs; mov vs r0 r5 LSR 25
};
const byte kInstruction_mov_pl_r7_r1_ASR_13[] = {
  0x58, 0xbf, 0x4f, 0x13 // It pl; mov pl r7 r1 ASR 13
};
const byte kInstruction_mov_le_r7_r0_LSR_28[] = {
  0xd8, 0xbf, 0x07, 0x0f // It le; mov le r7 r0 LSR 28
};
const byte kInstruction_mov_vs_r2_r5_LSR_25[] = {
  0x68, 0xbf, 0x6a, 0x0e // It vs; mov vs r2 r5 LSR 25
};
const byte kInstruction_mov_cs_r0_r5_LSR_14[] = {
  0x28, 0xbf, 0xa8, 0x0b // It cs; mov cs r0 r5 LSR 14
};
const byte kInstruction_mov_cs_r0_r5_ASR_31[] = {
  0x28, 0xbf, 0xe8, 0x17 // It cs; mov cs r0 r5 ASR 31
};
const byte kInstruction_mov_pl_r5_r5_ASR_13[] = {
  0x58, 0xbf, 0x6d, 0x13 // It pl; mov pl r5 r5 ASR 13
};
const byte kInstruction_mov_vc_r2_r1_LSR_18[] = {
  0x78, 0xbf, 0x8a, 0x0c // It vc; mov vc r2 r1 LSR 18
};
const byte kInstruction_mov_hi_r2_r1_ASR_31[] = {
  0x88, 0xbf, 0xca, 0x17 // It hi; mov hi r2 r1 ASR 31
};
const byte kInstruction_mov_cc_r6_r0_LSR_11[] = {
  0x38, 0xbf, 0xc6, 0x0a // It cc; mov cc r6 r0 LSR 11
};
const byte kInstruction_mov_pl_r6_r0_LSR_1[] = {
  0x58, 0xbf, 0x46, 0x08 // It pl; mov pl r6 r0 LSR 1
};
const byte kInstruction_mov_lt_r5_r1_LSR_3[] = {
  0xb8, 0xbf, 0xcd, 0x08 // It lt; mov lt r5 r1 LSR 3
};
const byte kInstruction_mov_eq_r3_r6_LSR_2[] = {
  0x08, 0xbf, 0xb3, 0x08 // It eq; mov eq r3 r6 LSR 2
};
const byte kInstruction_mov_mi_r7_r3_ASR_5[] = {
  0x48, 0xbf, 0x5f, 0x11 // It mi; mov mi r7 r3 ASR 5
};
const byte kInstruction_mov_vs_r5_r5_LSR_3[] = {
  0x68, 0xbf, 0xed, 0x08 // It vs; mov vs r5 r5 LSR 3
};
const byte kInstruction_mov_hi_r5_r3_ASR_18[] = {
  0x88, 0xbf, 0x9d, 0x14 // It hi; mov hi r5 r3 ASR 18
};
const byte kInstruction_mov_cc_r1_r6_ASR_13[] = {
  0x38, 0xbf, 0x71, 0x13 // It cc; mov cc r1 r6 ASR 13
};
const byte kInstruction_mov_vs_r7_r1_LSR_25[] = {
  0x68, 0xbf, 0x4f, 0x0e // It vs; mov vs r7 r1 LSR 25
};
const byte kInstruction_mov_lt_r1_r4_ASR_22[] = {
  0xb8, 0xbf, 0xa1, 0x15 // It lt; mov lt r1 r4 ASR 22
};
const byte kInstruction_mov_ls_r4_r5_LSR_13[] = {
  0x98, 0xbf, 0x6c, 0x0b // It ls; mov ls r4 r5 LSR 13
};
const byte kInstruction_mov_cc_r4_r7_LSR_26[] = {
  0x38, 0xbf, 0xbc, 0x0e // It cc; mov cc r4 r7 LSR 26
};
const byte kInstruction_mov_cs_r7_r7_LSR_21[] = {
  0x28, 0xbf, 0x7f, 0x0d // It cs; mov cs r7 r7 LSR 21
};
const byte kInstruction_mov_lt_r4_r4_ASR_2[] = {
  0xb8, 0xbf, 0xa4, 0x10 // It lt; mov lt r4 r4 ASR 2
};
const byte kInstruction_mov_eq_r7_r1_ASR_22[] = {
  0x08, 0xbf, 0x8f, 0x15 // It eq; mov eq r7 r1 ASR 22
};
const byte kInstruction_mov_vc_r7_r6_ASR_32[] = {
  0x78, 0xbf, 0x37, 0x10 // It vc; mov vc r7 r6 ASR 32
};
const byte kInstruction_mov_cs_r1_r7_LSR_5[] = {
  0x28, 0xbf, 0x79, 0x09 // It cs; mov cs r1 r7 LSR 5
};
const byte kInstruction_mov_vs_r6_r2_LSR_19[] = {
  0x68, 0xbf, 0xd6, 0x0c // It vs; mov vs r6 r2 LSR 19
};
const byte kInstruction_mov_cs_r3_r2_ASR_16[] = {
  0x28, 0xbf, 0x13, 0x14 // It cs; mov cs r3 r2 ASR 16
};
const byte kInstruction_mov_vs_r2_r3_LSR_27[] = {
  0x68, 0xbf, 0xda, 0x0e // It vs; mov vs r2 r3 LSR 27
};
const byte kInstruction_mov_pl_r3_r3_LSR_29[] = {
  0x58, 0xbf, 0x5b, 0x0f // It pl; mov pl r3 r3 LSR 29
};
const byte kInstruction_mov_lt_r3_r4_LSR_24[] = {
  0xb8, 0xbf, 0x23, 0x0e // It lt; mov lt r3 r4 LSR 24
};
const byte kInstruction_mov_le_r0_r4_LSR_15[] = {
  0xd8, 0xbf, 0xe0, 0x0b // It le; mov le r0 r4 LSR 15
};
const byte kInstruction_mov_ne_r6_r1_ASR_8[] = {
  0x18, 0xbf, 0x0e, 0x12 // It ne; mov ne r6 r1 ASR 8
};
const byte kInstruction_mov_pl_r2_r1_LSR_31[] = {
  0x58, 0xbf, 0xca, 0x0f // It pl; mov pl r2 r1 LSR 31
};
const byte kInstruction_mov_vs_r1_r4_ASR_19[] = {
  0x68, 0xbf, 0xe1, 0x14 // It vs; mov vs r1 r4 ASR 19
};
const byte kInstruction_mov_pl_r4_r1_LSR_15[] = {
  0x58, 0xbf, 0xcc, 0x0b // It pl; mov pl r4 r1 LSR 15
};
const byte kInstruction_mov_pl_r0_r7_LSR_10[] = {
  0x58, 0xbf, 0xb8, 0x0a // It pl; mov pl r0 r7 LSR 10
};
const byte kInstruction_mov_eq_r6_r0_ASR_7[] = {
  0x08, 0xbf, 0xc6, 0x11 // It eq; mov eq r6 r0 ASR 7
};
const byte kInstruction_mov_ne_r2_r6_LSR_12[] = {
  0x18, 0xbf, 0x32, 0x0b // It ne; mov ne r2 r6 LSR 12
};
const byte kInstruction_mov_ls_r0_r3_ASR_4[] = {
  0x98, 0xbf, 0x18, 0x11 // It ls; mov ls r0 r3 ASR 4
};
const byte kInstruction_mov_cs_r3_r5_ASR_11[] = {
  0x28, 0xbf, 0xeb, 0x12 // It cs; mov cs r3 r5 ASR 11
};
const byte kInstruction_mov_gt_r7_r0_ASR_19[] = {
  0xc8, 0xbf, 0xc7, 0x14 // It gt; mov gt r7 r0 ASR 19
};
const TestResult kReferencemov[] = {
  {
    ARRAY_SIZE(kInstruction_mov_ge_r7_r6_LSR_20),
    kInstruction_mov_ge_r7_r6_LSR_20,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r4_r6_LSR_32),
    kInstruction_mov_gt_r4_r6_LSR_32,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r6_r7_LSR_29),
    kInstruction_mov_hi_r6_r7_LSR_29,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r7_r1_LSR_10),
    kInstruction_mov_mi_r7_r1_LSR_10,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r7_r6_LSR_14),
    kInstruction_mov_ls_r7_r6_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r7_r2_ASR_14),
    kInstruction_mov_eq_r7_r2_ASR_14,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r3_r7_LSR_2),
    kInstruction_mov_le_r3_r7_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r2_r7_LSR_32),
    kInstruction_mov_mi_r2_r7_LSR_32,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r5_r0_ASR_23),
    kInstruction_mov_ge_r5_r0_ASR_23,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r3_r7_LSR_28),
    kInstruction_mov_ne_r3_r7_LSR_28,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r6_r4_LSR_13),
    kInstruction_mov_gt_r6_r4_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r6_r5_LSR_12),
    kInstruction_mov_hi_r6_r5_LSR_12,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r6_r1_ASR_12),
    kInstruction_mov_pl_r6_r1_ASR_12,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r7_r1_ASR_30),
    kInstruction_mov_hi_r7_r1_ASR_30,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r7_r6_ASR_20),
    kInstruction_mov_mi_r7_r6_ASR_20,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r3_r6_ASR_22),
    kInstruction_mov_cc_r3_r6_ASR_22,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r2_r1_ASR_29),
    kInstruction_mov_vc_r2_r1_ASR_29,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r0_r1_ASR_15),
    kInstruction_mov_pl_r0_r1_ASR_15,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r2_r1_LSR_22),
    kInstruction_mov_mi_r2_r1_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r6_r4_ASR_6),
    kInstruction_mov_pl_r6_r4_ASR_6,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r1_r3_ASR_15),
    kInstruction_mov_hi_r1_r3_ASR_15,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r3_r5_ASR_13),
    kInstruction_mov_eq_r3_r5_ASR_13,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r4_r6_ASR_31),
    kInstruction_mov_le_r4_r6_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r5_r1_ASR_15),
    kInstruction_mov_gt_r5_r1_ASR_15,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r3_r7_ASR_29),
    kInstruction_mov_pl_r3_r7_ASR_29,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r3_r1_ASR_15),
    kInstruction_mov_cs_r3_r1_ASR_15,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r1_r7_ASR_32),
    kInstruction_mov_le_r1_r7_ASR_32,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r5_r7_LSR_5),
    kInstruction_mov_vs_r5_r7_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r3_r1_ASR_30),
    kInstruction_mov_cs_r3_r1_ASR_30,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r7_r0_LSR_26),
    kInstruction_mov_gt_r7_r0_LSR_26,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r2_r6_LSR_24),
    kInstruction_mov_ne_r2_r6_LSR_24,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r2_r3_ASR_5),
    kInstruction_mov_pl_r2_r3_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r3_r4_ASR_30),
    kInstruction_mov_le_r3_r4_ASR_30,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r5_r7_ASR_13),
    kInstruction_mov_cs_r5_r7_ASR_13,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r0_r1_LSR_31),
    kInstruction_mov_eq_r0_r1_LSR_31,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r7_r2_LSR_2),
    kInstruction_mov_eq_r7_r2_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r2_r5_ASR_30),
    kInstruction_mov_vc_r2_r5_ASR_30,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r2_r1_ASR_5),
    kInstruction_mov_eq_r2_r1_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r4_r7_LSR_10),
    kInstruction_mov_le_r4_r7_LSR_10,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r6_r1_ASR_13),
    kInstruction_mov_cs_r6_r1_ASR_13,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r7_r4_LSR_26),
    kInstruction_mov_ls_r7_r4_LSR_26,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r7_r3_ASR_28),
    kInstruction_mov_ge_r7_r3_ASR_28,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r4_r4_LSR_16),
    kInstruction_mov_mi_r4_r4_LSR_16,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r3_r7_LSR_23),
    kInstruction_mov_ge_r3_r7_LSR_23,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r3_r3_LSR_25),
    kInstruction_mov_ge_r3_r3_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r2_r2_ASR_19),
    kInstruction_mov_ne_r2_r2_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r0_r5_LSR_29),
    kInstruction_mov_hi_r0_r5_LSR_29,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r0_r0_ASR_18),
    kInstruction_mov_vc_r0_r0_ASR_18,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r5_r3_ASR_3),
    kInstruction_mov_gt_r5_r3_ASR_3,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r6_r2_ASR_28),
    kInstruction_mov_mi_r6_r2_ASR_28,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r2_r6_LSR_31),
    kInstruction_mov_ls_r2_r6_LSR_31,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r4_r0_LSR_5),
    kInstruction_mov_cs_r4_r0_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r6_r2_ASR_17),
    kInstruction_mov_eq_r6_r2_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r7_r5_LSR_2),
    kInstruction_mov_cs_r7_r5_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r5_r3_LSR_17),
    kInstruction_mov_vc_r5_r3_LSR_17,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r5_r1_LSR_12),
    kInstruction_mov_pl_r5_r1_LSR_12,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r2_r1_LSR_2),
    kInstruction_mov_lt_r2_r1_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r6_r5_ASR_3),
    kInstruction_mov_hi_r6_r5_ASR_3,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r1_r6_ASR_19),
    kInstruction_mov_gt_r1_r6_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r3_r7_ASR_24),
    kInstruction_mov_ne_r3_r7_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r3_r2_ASR_27),
    kInstruction_mov_mi_r3_r2_ASR_27,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r0_r5_ASR_24),
    kInstruction_mov_ge_r0_r5_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r0_r2_ASR_12),
    kInstruction_mov_hi_r0_r2_ASR_12,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r4_r7_LSR_8),
    kInstruction_mov_vs_r4_r7_LSR_8,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r0_r4_LSR_6),
    kInstruction_mov_vc_r0_r4_LSR_6,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r3_r7_LSR_2),
    kInstruction_mov_cs_r3_r7_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r2_r3_ASR_7),
    kInstruction_mov_cc_r2_r3_ASR_7,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r5_r4_LSR_26),
    kInstruction_mov_lt_r5_r4_LSR_26,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r6_r3_LSR_16),
    kInstruction_mov_vs_r6_r3_LSR_16,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r5_r3_ASR_19),
    kInstruction_mov_hi_r5_r3_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r3_r6_LSR_16),
    kInstruction_mov_cc_r3_r6_LSR_16,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r0_r6_LSR_31),
    kInstruction_mov_cc_r0_r6_LSR_31,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r6_r7_ASR_32),
    kInstruction_mov_hi_r6_r7_ASR_32,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r3_r4_ASR_12),
    kInstruction_mov_vc_r3_r4_ASR_12,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r5_r7_ASR_9),
    kInstruction_mov_cs_r5_r7_ASR_9,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r5_r0_ASR_4),
    kInstruction_mov_lt_r5_r0_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r3_r1_ASR_17),
    kInstruction_mov_cc_r3_r1_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r7_r4_ASR_16),
    kInstruction_mov_vs_r7_r4_ASR_16,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r7_r6_ASR_14),
    kInstruction_mov_eq_r7_r6_ASR_14,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r1_r0_ASR_21),
    kInstruction_mov_ne_r1_r0_ASR_21,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r0_r1_LSR_19),
    kInstruction_mov_ls_r0_r1_LSR_19,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r1_r7_ASR_6),
    kInstruction_mov_cc_r1_r7_ASR_6,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r5_r2_LSR_1),
    kInstruction_mov_lt_r5_r2_LSR_1,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r7_r0_LSR_13),
    kInstruction_mov_lt_r7_r0_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r2_r6_ASR_14),
    kInstruction_mov_gt_r2_r6_ASR_14,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r5_r5_ASR_23),
    kInstruction_mov_ls_r5_r5_ASR_23,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r1_r1_ASR_12),
    kInstruction_mov_cs_r1_r1_ASR_12,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r0_r2_LSR_3),
    kInstruction_mov_pl_r0_r2_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r0_r1_LSR_5),
    kInstruction_mov_le_r0_r1_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r0_r5_LSR_29),
    kInstruction_mov_ne_r0_r5_LSR_29,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r6_r5_LSR_14),
    kInstruction_mov_vs_r6_r5_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r1_r7_ASR_25),
    kInstruction_mov_hi_r1_r7_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r2_r5_ASR_24),
    kInstruction_mov_mi_r2_r5_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r3_r4_ASR_3),
    kInstruction_mov_vc_r3_r4_ASR_3,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r4_r0_LSR_29),
    kInstruction_mov_cs_r4_r0_LSR_29,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r6_r6_ASR_24),
    kInstruction_mov_ne_r6_r6_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r1_r1_LSR_1),
    kInstruction_mov_lt_r1_r1_LSR_1,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r5_r3_ASR_8),
    kInstruction_mov_gt_r5_r3_ASR_8,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r4_r3_LSR_10),
    kInstruction_mov_mi_r4_r3_LSR_10,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r0_r4_LSR_24),
    kInstruction_mov_ge_r0_r4_LSR_24,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r0_r5_LSR_17),
    kInstruction_mov_hi_r0_r5_LSR_17,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r6_r7_ASR_12),
    kInstruction_mov_gt_r6_r7_ASR_12,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r2_r2_LSR_15),
    kInstruction_mov_mi_r2_r2_LSR_15,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r3_r0_ASR_1),
    kInstruction_mov_ls_r3_r0_ASR_1,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r4_r0_LSR_5),
    kInstruction_mov_lt_r4_r0_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r0_r1_LSR_18),
    kInstruction_mov_hi_r0_r1_LSR_18,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r6_r4_LSR_28),
    kInstruction_mov_hi_r6_r4_LSR_28,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r1_r1_LSR_24),
    kInstruction_mov_pl_r1_r1_LSR_24,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r6_r0_ASR_8),
    kInstruction_mov_vs_r6_r0_ASR_8,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r3_r4_LSR_8),
    kInstruction_mov_vs_r3_r4_LSR_8,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r2_r6_LSR_13),
    kInstruction_mov_cs_r2_r6_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r7_r6_ASR_15),
    kInstruction_mov_lt_r7_r6_ASR_15,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r6_r1_ASR_32),
    kInstruction_mov_le_r6_r1_ASR_32,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r7_r5_LSR_3),
    kInstruction_mov_cc_r7_r5_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r5_r1_LSR_7),
    kInstruction_mov_hi_r5_r1_LSR_7,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r5_r4_LSR_5),
    kInstruction_mov_lt_r5_r4_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r4_r2_LSR_9),
    kInstruction_mov_mi_r4_r2_LSR_9,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r3_r3_ASR_10),
    kInstruction_mov_pl_r3_r3_ASR_10,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r3_r7_LSR_17),
    kInstruction_mov_ge_r3_r7_LSR_17,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r4_r1_LSR_5),
    kInstruction_mov_ls_r4_r1_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r4_r3_LSR_28),
    kInstruction_mov_mi_r4_r3_LSR_28,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r7_r1_ASR_14),
    kInstruction_mov_ne_r7_r1_ASR_14,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r7_r7_ASR_20),
    kInstruction_mov_ge_r7_r7_ASR_20,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r2_r3_LSR_11),
    kInstruction_mov_ne_r2_r3_LSR_11,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r6_r5_ASR_15),
    kInstruction_mov_lt_r6_r5_ASR_15,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r6_r7_ASR_3),
    kInstruction_mov_cs_r6_r7_ASR_3,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r7_r7_LSR_12),
    kInstruction_mov_hi_r7_r7_LSR_12,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r2_r4_ASR_4),
    kInstruction_mov_cs_r2_r4_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r7_r7_ASR_3),
    kInstruction_mov_lt_r7_r7_ASR_3,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r1_r3_ASR_27),
    kInstruction_mov_le_r1_r3_ASR_27,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r2_r3_LSR_28),
    kInstruction_mov_vs_r2_r3_LSR_28,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r2_r0_ASR_8),
    kInstruction_mov_pl_r2_r0_ASR_8,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r5_r2_ASR_15),
    kInstruction_mov_hi_r5_r2_ASR_15,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r6_r0_LSR_5),
    kInstruction_mov_vs_r6_r0_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r1_r6_ASR_22),
    kInstruction_mov_le_r1_r6_ASR_22,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r3_r2_ASR_17),
    kInstruction_mov_hi_r3_r2_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r1_r5_ASR_16),
    kInstruction_mov_gt_r1_r5_ASR_16,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r2_r0_ASR_26),
    kInstruction_mov_hi_r2_r0_ASR_26,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r1_r4_LSR_27),
    kInstruction_mov_vs_r1_r4_LSR_27,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r3_r4_ASR_15),
    kInstruction_mov_ls_r3_r4_ASR_15,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r7_r4_LSR_15),
    kInstruction_mov_ge_r7_r4_LSR_15,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r7_r2_LSR_21),
    kInstruction_mov_vc_r7_r2_LSR_21,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r2_r7_ASR_22),
    kInstruction_mov_ls_r2_r7_ASR_22,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r5_r5_LSR_21),
    kInstruction_mov_pl_r5_r5_LSR_21,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r2_r4_ASR_25),
    kInstruction_mov_cs_r2_r4_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r7_r6_LSR_5),
    kInstruction_mov_gt_r7_r6_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r5_r6_ASR_25),
    kInstruction_mov_gt_r5_r6_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r3_r0_LSR_30),
    kInstruction_mov_vs_r3_r0_LSR_30,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r6_r0_LSR_17),
    kInstruction_mov_pl_r6_r0_LSR_17,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r6_r2_ASR_7),
    kInstruction_mov_pl_r6_r2_ASR_7,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r4_r4_LSR_17),
    kInstruction_mov_lt_r4_r4_LSR_17,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r4_r5_LSR_3),
    kInstruction_mov_vc_r4_r5_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r4_r4_ASR_21),
    kInstruction_mov_cc_r4_r4_ASR_21,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r4_r2_ASR_10),
    kInstruction_mov_vs_r4_r2_ASR_10,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r7_r4_ASR_10),
    kInstruction_mov_cs_r7_r4_ASR_10,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r6_r1_LSR_17),
    kInstruction_mov_hi_r6_r1_LSR_17,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r4_r6_LSR_24),
    kInstruction_mov_vc_r4_r6_LSR_24,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r3_r2_ASR_7),
    kInstruction_mov_pl_r3_r2_ASR_7,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r3_r7_LSR_17),
    kInstruction_mov_mi_r3_r7_LSR_17,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r7_r3_ASR_7),
    kInstruction_mov_pl_r7_r3_ASR_7,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r0_r4_LSR_10),
    kInstruction_mov_vc_r0_r4_LSR_10,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r2_r1_ASR_24),
    kInstruction_mov_le_r2_r1_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r2_r7_LSR_11),
    kInstruction_mov_le_r2_r7_LSR_11,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r6_r0_ASR_13),
    kInstruction_mov_cs_r6_r0_ASR_13,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r3_r0_ASR_27),
    kInstruction_mov_ge_r3_r0_ASR_27,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r6_r0_ASR_17),
    kInstruction_mov_cc_r6_r0_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r7_r7_ASR_6),
    kInstruction_mov_hi_r7_r7_ASR_6,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r6_r7_LSR_21),
    kInstruction_mov_vc_r6_r7_LSR_21,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r6_r4_ASR_25),
    kInstruction_mov_ge_r6_r4_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r5_r2_ASR_7),
    kInstruction_mov_gt_r5_r2_ASR_7,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r6_r1_LSR_8),
    kInstruction_mov_gt_r6_r1_LSR_8,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r1_r6_ASR_13),
    kInstruction_mov_le_r1_r6_ASR_13,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r6_r0_ASR_24),
    kInstruction_mov_hi_r6_r0_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r1_r5_ASR_29),
    kInstruction_mov_le_r1_r5_ASR_29,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r5_r1_ASR_23),
    kInstruction_mov_vs_r5_r1_ASR_23,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r0_r6_LSR_7),
    kInstruction_mov_le_r0_r6_LSR_7,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r7_r1_LSR_17),
    kInstruction_mov_pl_r7_r1_LSR_17,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r4_r7_ASR_5),
    kInstruction_mov_ne_r4_r7_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r5_r5_LSR_22),
    kInstruction_mov_ne_r5_r5_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r7_r2_ASR_29),
    kInstruction_mov_lt_r7_r2_ASR_29,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r5_r3_LSR_28),
    kInstruction_mov_le_r5_r3_LSR_28,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r7_r5_ASR_29),
    kInstruction_mov_eq_r7_r5_ASR_29,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r2_r6_LSR_4),
    kInstruction_mov_cs_r2_r6_LSR_4,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r1_r0_LSR_17),
    kInstruction_mov_ne_r1_r0_LSR_17,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r2_r6_ASR_28),
    kInstruction_mov_ls_r2_r6_ASR_28,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r5_r7_ASR_32),
    kInstruction_mov_ge_r5_r7_ASR_32,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r0_r0_ASR_1),
    kInstruction_mov_cs_r0_r0_ASR_1,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r6_r5_LSR_11),
    kInstruction_mov_mi_r6_r5_LSR_11,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r5_r3_ASR_29),
    kInstruction_mov_mi_r5_r3_ASR_29,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r2_r2_LSR_30),
    kInstruction_mov_eq_r2_r2_LSR_30,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r4_r2_ASR_25),
    kInstruction_mov_mi_r4_r2_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r5_r0_LSR_13),
    kInstruction_mov_cs_r5_r0_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r7_r4_ASR_10),
    kInstruction_mov_cc_r7_r4_ASR_10,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r1_r5_LSR_21),
    kInstruction_mov_mi_r1_r5_LSR_21,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r3_r2_LSR_2),
    kInstruction_mov_vs_r3_r2_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r4_r4_ASR_14),
    kInstruction_mov_ls_r4_r4_ASR_14,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r5_r4_LSR_23),
    kInstruction_mov_eq_r5_r4_LSR_23,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r7_r1_ASR_20),
    kInstruction_mov_gt_r7_r1_ASR_20,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r2_r5_ASR_5),
    kInstruction_mov_vs_r2_r5_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r6_r0_LSR_14),
    kInstruction_mov_le_r6_r0_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r6_r5_LSR_14),
    kInstruction_mov_cs_r6_r5_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r7_r4_ASR_22),
    kInstruction_mov_ls_r7_r4_ASR_22,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r3_r2_ASR_1),
    kInstruction_mov_cs_r3_r2_ASR_1,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r7_r1_LSR_30),
    kInstruction_mov_ne_r7_r1_LSR_30,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r3_r6_LSR_32),
    kInstruction_mov_ge_r3_r6_LSR_32,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r2_r5_ASR_11),
    kInstruction_mov_ne_r2_r5_ASR_11,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r4_r4_LSR_4),
    kInstruction_mov_cc_r4_r4_LSR_4,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r6_r0_ASR_31),
    kInstruction_mov_lt_r6_r0_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r7_r0_LSR_26),
    kInstruction_mov_cc_r7_r0_LSR_26,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r1_r4_LSR_31),
    kInstruction_mov_vs_r1_r4_LSR_31,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r3_r6_LSR_11),
    kInstruction_mov_vc_r3_r6_LSR_11,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r0_r4_LSR_26),
    kInstruction_mov_cs_r0_r4_LSR_26,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r0_r6_ASR_31),
    kInstruction_mov_eq_r0_r6_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r0_r1_ASR_27),
    kInstruction_mov_eq_r0_r1_ASR_27,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r2_r0_LSR_16),
    kInstruction_mov_ls_r2_r0_LSR_16,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r1_r7_LSR_10),
    kInstruction_mov_vs_r1_r7_LSR_10,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r1_r2_ASR_7),
    kInstruction_mov_gt_r1_r2_ASR_7,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r6_r5_LSR_6),
    kInstruction_mov_vc_r6_r5_LSR_6,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r7_r2_ASR_4),
    kInstruction_mov_ge_r7_r2_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r6_r0_LSR_24),
    kInstruction_mov_cs_r6_r0_LSR_24,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r3_r0_LSR_25),
    kInstruction_mov_vc_r3_r0_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r6_r6_ASR_4),
    kInstruction_mov_vc_r6_r6_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r1_r3_LSR_15),
    kInstruction_mov_vc_r1_r3_LSR_15,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r4_r2_ASR_26),
    kInstruction_mov_cc_r4_r2_ASR_26,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r2_r2_LSR_10),
    kInstruction_mov_pl_r2_r2_LSR_10,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r3_r0_LSR_27),
    kInstruction_mov_pl_r3_r0_LSR_27,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r7_r7_LSR_21),
    kInstruction_mov_pl_r7_r7_LSR_21,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r3_r3_LSR_31),
    kInstruction_mov_le_r3_r3_LSR_31,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r2_r2_LSR_10),
    kInstruction_mov_ge_r2_r2_LSR_10,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r2_r1_LSR_20),
    kInstruction_mov_le_r2_r1_LSR_20,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r3_r3_LSR_4),
    kInstruction_mov_eq_r3_r3_LSR_4,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r3_r6_ASR_7),
    kInstruction_mov_mi_r3_r6_ASR_7,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r2_r6_ASR_29),
    kInstruction_mov_hi_r2_r6_ASR_29,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r2_r0_LSR_14),
    kInstruction_mov_pl_r2_r0_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r0_r7_ASR_26),
    kInstruction_mov_gt_r0_r7_ASR_26,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r1_r6_LSR_20),
    kInstruction_mov_lt_r1_r6_LSR_20,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r7_r1_ASR_20),
    kInstruction_mov_le_r7_r1_ASR_20,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r5_r5_LSR_7),
    kInstruction_mov_mi_r5_r5_LSR_7,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r2_r3_LSR_23),
    kInstruction_mov_cc_r2_r3_LSR_23,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r4_r2_LSR_4),
    kInstruction_mov_gt_r4_r2_LSR_4,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r3_r0_LSR_32),
    kInstruction_mov_vc_r3_r0_LSR_32,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r4_r0_LSR_15),
    kInstruction_mov_mi_r4_r0_LSR_15,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r4_r2_ASR_19),
    kInstruction_mov_pl_r4_r2_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r3_r3_ASR_3),
    kInstruction_mov_ge_r3_r3_ASR_3,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r4_r1_ASR_11),
    kInstruction_mov_cc_r4_r1_ASR_11,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r4_r1_LSR_14),
    kInstruction_mov_ne_r4_r1_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r4_r7_ASR_29),
    kInstruction_mov_hi_r4_r7_ASR_29,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r0_r2_LSR_6),
    kInstruction_mov_ls_r0_r2_LSR_6,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r3_r0_LSR_18),
    kInstruction_mov_hi_r3_r0_LSR_18,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r2_r5_ASR_27),
    kInstruction_mov_ge_r2_r5_ASR_27,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r6_r3_ASR_10),
    kInstruction_mov_vs_r6_r3_ASR_10,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r7_r2_LSR_19),
    kInstruction_mov_cs_r7_r2_LSR_19,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r2_r6_ASR_4),
    kInstruction_mov_vs_r2_r6_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r3_r2_ASR_26),
    kInstruction_mov_vs_r3_r2_ASR_26,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r3_r3_LSR_14),
    kInstruction_mov_gt_r3_r3_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r1_r3_ASR_20),
    kInstruction_mov_mi_r1_r3_ASR_20,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r2_r0_LSR_3),
    kInstruction_mov_eq_r2_r0_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r4_r3_LSR_14),
    kInstruction_mov_lt_r4_r3_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r2_r7_ASR_13),
    kInstruction_mov_vs_r2_r7_ASR_13,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r4_r1_ASR_31),
    kInstruction_mov_ls_r4_r1_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r4_r3_ASR_17),
    kInstruction_mov_le_r4_r3_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r7_r0_LSR_14),
    kInstruction_mov_mi_r7_r0_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r5_r6_LSR_6),
    kInstruction_mov_ne_r5_r6_LSR_6,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r5_r2_LSR_6),
    kInstruction_mov_lt_r5_r2_LSR_6,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r6_r1_ASR_30),
    kInstruction_mov_gt_r6_r1_ASR_30,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r7_r7_ASR_30),
    kInstruction_mov_ne_r7_r7_ASR_30,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r5_r1_ASR_25),
    kInstruction_mov_ls_r5_r1_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r3_r2_LSR_29),
    kInstruction_mov_lt_r3_r2_LSR_29,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r6_r1_LSR_6),
    kInstruction_mov_le_r6_r1_LSR_6,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r7_r6_ASR_12),
    kInstruction_mov_gt_r7_r6_ASR_12,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r6_r2_ASR_10),
    kInstruction_mov_ls_r6_r2_ASR_10,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r7_r7_LSR_6),
    kInstruction_mov_ne_r7_r7_LSR_6,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r0_r3_ASR_5),
    kInstruction_mov_mi_r0_r3_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r0_r4_LSR_3),
    kInstruction_mov_ne_r0_r4_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r3_r4_ASR_16),
    kInstruction_mov_ge_r3_r4_ASR_16,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r4_r5_ASR_19),
    kInstruction_mov_ls_r4_r5_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r1_r7_ASR_21),
    kInstruction_mov_eq_r1_r7_ASR_21,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r6_r4_ASR_30),
    kInstruction_mov_hi_r6_r4_ASR_30,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r7_r1_LSR_3),
    kInstruction_mov_eq_r7_r1_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r6_r2_ASR_12),
    kInstruction_mov_pl_r6_r2_ASR_12,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r6_r3_LSR_28),
    kInstruction_mov_eq_r6_r3_LSR_28,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r6_r6_LSR_5),
    kInstruction_mov_cc_r6_r6_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r2_r4_ASR_3),
    kInstruction_mov_le_r2_r4_ASR_3,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r7_r4_LSR_30),
    kInstruction_mov_vc_r7_r4_LSR_30,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r0_r0_LSR_25),
    kInstruction_mov_ge_r0_r0_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r0_r2_ASR_27),
    kInstruction_mov_ls_r0_r2_ASR_27,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r5_r6_LSR_22),
    kInstruction_mov_cc_r5_r6_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r0_r4_LSR_17),
    kInstruction_mov_lt_r0_r4_LSR_17,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r0_r4_ASR_1),
    kInstruction_mov_le_r0_r4_ASR_1,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r5_r5_ASR_6),
    kInstruction_mov_hi_r5_r5_ASR_6,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r7_r0_LSR_16),
    kInstruction_mov_vc_r7_r0_LSR_16,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r6_r1_ASR_16),
    kInstruction_mov_ne_r6_r1_ASR_16,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r7_r0_LSR_31),
    kInstruction_mov_vs_r7_r0_LSR_31,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r3_r2_ASR_18),
    kInstruction_mov_ne_r3_r2_ASR_18,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r2_r2_LSR_18),
    kInstruction_mov_vs_r2_r2_LSR_18,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r6_r2_ASR_25),
    kInstruction_mov_mi_r6_r2_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r7_r6_ASR_28),
    kInstruction_mov_hi_r7_r6_ASR_28,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r2_r1_ASR_3),
    kInstruction_mov_gt_r2_r1_ASR_3,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r0_r1_ASR_31),
    kInstruction_mov_ne_r0_r1_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r2_r7_ASR_24),
    kInstruction_mov_hi_r2_r7_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r2_r5_ASR_30),
    kInstruction_mov_hi_r2_r5_ASR_30,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r3_r2_ASR_11),
    kInstruction_mov_gt_r3_r2_ASR_11,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r4_r0_ASR_3),
    kInstruction_mov_ge_r4_r0_ASR_3,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r0_r4_LSR_19),
    kInstruction_mov_mi_r0_r4_LSR_19,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r0_r5_ASR_30),
    kInstruction_mov_gt_r0_r5_ASR_30,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r0_r3_LSR_16),
    kInstruction_mov_vs_r0_r3_LSR_16,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r4_r1_LSR_3),
    kInstruction_mov_ls_r4_r1_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r4_r3_ASR_17),
    kInstruction_mov_vc_r4_r3_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r0_r1_LSR_5),
    kInstruction_mov_gt_r0_r1_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r1_r4_ASR_6),
    kInstruction_mov_ls_r1_r4_ASR_6,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r1_r1_ASR_23),
    kInstruction_mov_ge_r1_r1_ASR_23,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r1_r3_ASR_28),
    kInstruction_mov_hi_r1_r3_ASR_28,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r1_r1_ASR_11),
    kInstruction_mov_vc_r1_r1_ASR_11,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r0_r4_ASR_24),
    kInstruction_mov_le_r0_r4_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r4_r7_LSR_4),
    kInstruction_mov_cc_r4_r7_LSR_4,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r6_r2_LSR_7),
    kInstruction_mov_hi_r6_r2_LSR_7,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r1_r1_LSR_22),
    kInstruction_mov_le_r1_r1_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r6_r4_LSR_6),
    kInstruction_mov_le_r6_r4_LSR_6,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r2_r5_ASR_11),
    kInstruction_mov_le_r2_r5_ASR_11,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r5_r1_ASR_2),
    kInstruction_mov_vc_r5_r1_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r7_r4_LSR_31),
    kInstruction_mov_lt_r7_r4_LSR_31,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r6_r1_LSR_28),
    kInstruction_mov_hi_r6_r1_LSR_28,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r7_r7_LSR_24),
    kInstruction_mov_ne_r7_r7_LSR_24,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r7_r6_LSR_32),
    kInstruction_mov_ge_r7_r6_LSR_32,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r6_r4_LSR_25),
    kInstruction_mov_hi_r6_r4_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r2_r6_ASR_3),
    kInstruction_mov_pl_r2_r6_ASR_3,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r5_r1_LSR_20),
    kInstruction_mov_ls_r5_r1_LSR_20,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r1_r1_LSR_10),
    kInstruction_mov_hi_r1_r1_LSR_10,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r6_r1_ASR_29),
    kInstruction_mov_lt_r6_r1_ASR_29,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r7_r5_ASR_14),
    kInstruction_mov_mi_r7_r5_ASR_14,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r1_r0_ASR_5),
    kInstruction_mov_le_r1_r0_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r7_r2_ASR_18),
    kInstruction_mov_gt_r7_r2_ASR_18,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r5_r4_LSR_12),
    kInstruction_mov_pl_r5_r4_LSR_12,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r1_r3_ASR_21),
    kInstruction_mov_mi_r1_r3_ASR_21,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r7_r7_LSR_13),
    kInstruction_mov_mi_r7_r7_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r1_r4_LSR_7),
    kInstruction_mov_gt_r1_r4_LSR_7,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r5_r5_ASR_28),
    kInstruction_mov_vc_r5_r5_ASR_28,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r3_r3_LSR_24),
    kInstruction_mov_mi_r3_r3_LSR_24,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r4_r7_LSR_32),
    kInstruction_mov_ls_r4_r7_LSR_32,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r1_r4_LSR_18),
    kInstruction_mov_mi_r1_r4_LSR_18,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r3_r6_LSR_10),
    kInstruction_mov_le_r3_r6_LSR_10,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r3_r3_ASR_17),
    kInstruction_mov_gt_r3_r3_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r1_r5_LSR_25),
    kInstruction_mov_ls_r1_r5_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r1_r0_ASR_11),
    kInstruction_mov_vs_r1_r0_ASR_11,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r0_r6_ASR_17),
    kInstruction_mov_cs_r0_r6_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r0_r6_LSR_14),
    kInstruction_mov_cs_r0_r6_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r4_r6_LSR_13),
    kInstruction_mov_lt_r4_r6_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r6_r4_ASR_23),
    kInstruction_mov_vs_r6_r4_ASR_23,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r4_r4_ASR_12),
    kInstruction_mov_cc_r4_r4_ASR_12,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r1_r6_LSR_28),
    kInstruction_mov_lt_r1_r6_LSR_28,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r4_r2_ASR_2),
    kInstruction_mov_cc_r4_r2_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r2_r0_ASR_27),
    kInstruction_mov_ls_r2_r0_ASR_27,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r6_r3_LSR_32),
    kInstruction_mov_le_r6_r3_LSR_32,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r6_r7_ASR_10),
    kInstruction_mov_cs_r6_r7_ASR_10,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r0_r1_ASR_31),
    kInstruction_mov_vs_r0_r1_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r2_r3_ASR_2),
    kInstruction_mov_vc_r2_r3_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r1_r7_ASR_24),
    kInstruction_mov_ge_r1_r7_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r3_r2_LSR_21),
    kInstruction_mov_eq_r3_r2_LSR_21,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r4_r3_ASR_22),
    kInstruction_mov_ge_r4_r3_ASR_22,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r2_r0_LSR_1),
    kInstruction_mov_hi_r2_r0_LSR_1,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r2_r4_LSR_9),
    kInstruction_mov_vs_r2_r4_LSR_9,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r5_r3_LSR_20),
    kInstruction_mov_ls_r5_r3_LSR_20,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r4_r0_ASR_5),
    kInstruction_mov_cs_r4_r0_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r6_r2_LSR_5),
    kInstruction_mov_lt_r6_r2_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r4_r6_LSR_24),
    kInstruction_mov_ls_r4_r6_LSR_24,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r6_r3_LSR_26),
    kInstruction_mov_le_r6_r3_LSR_26,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r4_r5_ASR_27),
    kInstruction_mov_ne_r4_r5_ASR_27,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r2_r1_LSR_19),
    kInstruction_mov_hi_r2_r1_LSR_19,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r2_r3_LSR_17),
    kInstruction_mov_mi_r2_r3_LSR_17,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r6_r4_LSR_3),
    kInstruction_mov_eq_r6_r4_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r3_r1_LSR_5),
    kInstruction_mov_ne_r3_r1_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r1_r4_ASR_4),
    kInstruction_mov_vs_r1_r4_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r0_r3_LSR_22),
    kInstruction_mov_ls_r0_r3_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r6_r4_LSR_1),
    kInstruction_mov_mi_r6_r4_LSR_1,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r5_r4_LSR_12),
    kInstruction_mov_hi_r5_r4_LSR_12,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r0_r3_LSR_3),
    kInstruction_mov_le_r0_r3_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r1_r6_LSR_30),
    kInstruction_mov_pl_r1_r6_LSR_30,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r7_r2_ASR_31),
    kInstruction_mov_ne_r7_r2_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r6_r2_ASR_11),
    kInstruction_mov_ge_r6_r2_ASR_11,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r0_r1_LSR_28),
    kInstruction_mov_pl_r0_r1_LSR_28,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r6_r4_LSR_23),
    kInstruction_mov_lt_r6_r4_LSR_23,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r2_r4_LSR_1),
    kInstruction_mov_mi_r2_r4_LSR_1,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r7_r3_ASR_18),
    kInstruction_mov_mi_r7_r3_ASR_18,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r4_r1_LSR_24),
    kInstruction_mov_ls_r4_r1_LSR_24,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r4_r4_ASR_7),
    kInstruction_mov_ne_r4_r4_ASR_7,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r4_r4_ASR_23),
    kInstruction_mov_lt_r4_r4_ASR_23,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r7_r2_ASR_24),
    kInstruction_mov_vs_r7_r2_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r2_r4_ASR_24),
    kInstruction_mov_cs_r2_r4_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r6_r0_LSR_9),
    kInstruction_mov_ge_r6_r0_LSR_9,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r2_r1_ASR_10),
    kInstruction_mov_mi_r2_r1_ASR_10,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r6_r3_ASR_13),
    kInstruction_mov_mi_r6_r3_ASR_13,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r4_r6_ASR_28),
    kInstruction_mov_vc_r4_r6_ASR_28,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r6_r7_ASR_1),
    kInstruction_mov_pl_r6_r7_ASR_1,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r1_r2_ASR_18),
    kInstruction_mov_gt_r1_r2_ASR_18,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r6_r2_LSR_32),
    kInstruction_mov_hi_r6_r2_LSR_32,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r3_r0_ASR_10),
    kInstruction_mov_eq_r3_r0_ASR_10,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r0_r3_ASR_8),
    kInstruction_mov_mi_r0_r3_ASR_8,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r6_r0_ASR_27),
    kInstruction_mov_pl_r6_r0_ASR_27,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r6_r4_ASR_28),
    kInstruction_mov_lt_r6_r4_ASR_28,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r6_r3_ASR_25),
    kInstruction_mov_ne_r6_r3_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r1_r1_LSR_16),
    kInstruction_mov_lt_r1_r1_LSR_16,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r4_r3_ASR_18),
    kInstruction_mov_vs_r4_r3_ASR_18,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r3_r5_LSR_16),
    kInstruction_mov_vs_r3_r5_LSR_16,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r6_r1_LSR_31),
    kInstruction_mov_le_r6_r1_LSR_31,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r6_r3_LSR_14),
    kInstruction_mov_ls_r6_r3_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r3_r6_ASR_17),
    kInstruction_mov_pl_r3_r6_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r7_r7_ASR_1),
    kInstruction_mov_vc_r7_r7_ASR_1,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r2_r0_ASR_17),
    kInstruction_mov_cc_r2_r0_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r7_r1_LSR_32),
    kInstruction_mov_le_r7_r1_LSR_32,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r1_r3_ASR_8),
    kInstruction_mov_eq_r1_r3_ASR_8,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r4_r5_LSR_18),
    kInstruction_mov_vc_r4_r5_LSR_18,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r0_r2_ASR_32),
    kInstruction_mov_hi_r0_r2_ASR_32,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r4_r6_ASR_4),
    kInstruction_mov_le_r4_r6_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r5_r5_ASR_7),
    kInstruction_mov_mi_r5_r5_ASR_7,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r6_r5_LSR_24),
    kInstruction_mov_eq_r6_r5_LSR_24,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r5_r5_ASR_9),
    kInstruction_mov_pl_r5_r5_ASR_9,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r6_r2_ASR_24),
    kInstruction_mov_ne_r6_r2_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r3_r7_ASR_3),
    kInstruction_mov_eq_r3_r7_ASR_3,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r6_r0_LSR_25),
    kInstruction_mov_lt_r6_r0_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r5_r5_ASR_8),
    kInstruction_mov_ls_r5_r5_ASR_8,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r5_r6_ASR_17),
    kInstruction_mov_hi_r5_r6_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r4_r0_ASR_18),
    kInstruction_mov_ne_r4_r0_ASR_18,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r2_r4_LSR_30),
    kInstruction_mov_mi_r2_r4_LSR_30,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r1_r6_ASR_5),
    kInstruction_mov_cc_r1_r6_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r7_r2_LSR_15),
    kInstruction_mov_hi_r7_r2_LSR_15,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r7_r7_ASR_29),
    kInstruction_mov_cc_r7_r7_ASR_29,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r7_r4_ASR_22),
    kInstruction_mov_eq_r7_r4_ASR_22,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r3_r3_ASR_2),
    kInstruction_mov_mi_r3_r3_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r2_r5_LSR_14),
    kInstruction_mov_le_r2_r5_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r6_r5_ASR_12),
    kInstruction_mov_pl_r6_r5_ASR_12,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r5_r6_LSR_11),
    kInstruction_mov_ne_r5_r6_LSR_11,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r0_r1_ASR_29),
    kInstruction_mov_cs_r0_r1_ASR_29,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r3_r6_LSR_5),
    kInstruction_mov_cc_r3_r6_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r5_r4_LSR_10),
    kInstruction_mov_ge_r5_r4_LSR_10,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r7_r5_ASR_9),
    kInstruction_mov_vs_r7_r5_ASR_9,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ge_r6_r4_LSR_22),
    kInstruction_mov_ge_r6_r4_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r0_r7_ASR_20),
    kInstruction_mov_vs_r0_r7_ASR_20,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r1_r5_LSR_21),
    kInstruction_mov_ls_r1_r5_LSR_21,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r3_r3_ASR_16),
    kInstruction_mov_cc_r3_r3_ASR_16,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r2_r3_ASR_30),
    kInstruction_mov_hi_r2_r3_ASR_30,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r5_r3_LSR_12),
    kInstruction_mov_cs_r5_r3_LSR_12,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r5_r5_ASR_24),
    kInstruction_mov_cc_r5_r5_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r7_r0_ASR_18),
    kInstruction_mov_vc_r7_r0_ASR_18,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r4_r7_ASR_30),
    kInstruction_mov_mi_r4_r7_ASR_30,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r6_r0_LSR_17),
    kInstruction_mov_vc_r6_r0_LSR_17,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r3_r3_ASR_2),
    kInstruction_mov_eq_r3_r3_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r5_r2_LSR_31),
    kInstruction_mov_ne_r5_r2_LSR_31,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r4_r2_ASR_6),
    kInstruction_mov_ne_r4_r2_ASR_6,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r3_r7_ASR_25),
    kInstruction_mov_eq_r3_r7_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r1_r7_LSR_11),
    kInstruction_mov_pl_r1_r7_LSR_11,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r4_r4_ASR_1),
    kInstruction_mov_lt_r4_r4_ASR_1,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r7_r4_LSR_8),
    kInstruction_mov_vc_r7_r4_LSR_8,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r1_r4_ASR_4),
    kInstruction_mov_ls_r1_r4_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r2_r4_LSR_18),
    kInstruction_mov_cc_r2_r4_LSR_18,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r0_r5_LSR_8),
    kInstruction_mov_gt_r0_r5_LSR_8,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r4_r1_LSR_4),
    kInstruction_mov_lt_r4_r1_LSR_4,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r7_r7_ASR_12),
    kInstruction_mov_gt_r7_r7_ASR_12,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r0_r6_LSR_28),
    kInstruction_mov_vs_r0_r6_LSR_28,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r0_r5_LSR_25),
    kInstruction_mov_vs_r0_r5_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r7_r1_ASR_13),
    kInstruction_mov_pl_r7_r1_ASR_13,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r7_r0_LSR_28),
    kInstruction_mov_le_r7_r0_LSR_28,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r2_r5_LSR_25),
    kInstruction_mov_vs_r2_r5_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r0_r5_LSR_14),
    kInstruction_mov_cs_r0_r5_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r0_r5_ASR_31),
    kInstruction_mov_cs_r0_r5_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r5_r5_ASR_13),
    kInstruction_mov_pl_r5_r5_ASR_13,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r2_r1_LSR_18),
    kInstruction_mov_vc_r2_r1_LSR_18,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r2_r1_ASR_31),
    kInstruction_mov_hi_r2_r1_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r6_r0_LSR_11),
    kInstruction_mov_cc_r6_r0_LSR_11,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r6_r0_LSR_1),
    kInstruction_mov_pl_r6_r0_LSR_1,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r5_r1_LSR_3),
    kInstruction_mov_lt_r5_r1_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r3_r6_LSR_2),
    kInstruction_mov_eq_r3_r6_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_mov_mi_r7_r3_ASR_5),
    kInstruction_mov_mi_r7_r3_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r5_r5_LSR_3),
    kInstruction_mov_vs_r5_r5_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_mov_hi_r5_r3_ASR_18),
    kInstruction_mov_hi_r5_r3_ASR_18,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r1_r6_ASR_13),
    kInstruction_mov_cc_r1_r6_ASR_13,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r7_r1_LSR_25),
    kInstruction_mov_vs_r7_r1_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r1_r4_ASR_22),
    kInstruction_mov_lt_r1_r4_ASR_22,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r4_r5_LSR_13),
    kInstruction_mov_ls_r4_r5_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cc_r4_r7_LSR_26),
    kInstruction_mov_cc_r4_r7_LSR_26,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r7_r7_LSR_21),
    kInstruction_mov_cs_r7_r7_LSR_21,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r4_r4_ASR_2),
    kInstruction_mov_lt_r4_r4_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r7_r1_ASR_22),
    kInstruction_mov_eq_r7_r1_ASR_22,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vc_r7_r6_ASR_32),
    kInstruction_mov_vc_r7_r6_ASR_32,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r1_r7_LSR_5),
    kInstruction_mov_cs_r1_r7_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r6_r2_LSR_19),
    kInstruction_mov_vs_r6_r2_LSR_19,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r3_r2_ASR_16),
    kInstruction_mov_cs_r3_r2_ASR_16,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r2_r3_LSR_27),
    kInstruction_mov_vs_r2_r3_LSR_27,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r3_r3_LSR_29),
    kInstruction_mov_pl_r3_r3_LSR_29,
  },
  {
    ARRAY_SIZE(kInstruction_mov_lt_r3_r4_LSR_24),
    kInstruction_mov_lt_r3_r4_LSR_24,
  },
  {
    ARRAY_SIZE(kInstruction_mov_le_r0_r4_LSR_15),
    kInstruction_mov_le_r0_r4_LSR_15,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r6_r1_ASR_8),
    kInstruction_mov_ne_r6_r1_ASR_8,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r2_r1_LSR_31),
    kInstruction_mov_pl_r2_r1_LSR_31,
  },
  {
    ARRAY_SIZE(kInstruction_mov_vs_r1_r4_ASR_19),
    kInstruction_mov_vs_r1_r4_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r4_r1_LSR_15),
    kInstruction_mov_pl_r4_r1_LSR_15,
  },
  {
    ARRAY_SIZE(kInstruction_mov_pl_r0_r7_LSR_10),
    kInstruction_mov_pl_r0_r7_LSR_10,
  },
  {
    ARRAY_SIZE(kInstruction_mov_eq_r6_r0_ASR_7),
    kInstruction_mov_eq_r6_r0_ASR_7,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ne_r2_r6_LSR_12),
    kInstruction_mov_ne_r2_r6_LSR_12,
  },
  {
    ARRAY_SIZE(kInstruction_mov_ls_r0_r3_ASR_4),
    kInstruction_mov_ls_r0_r3_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_mov_cs_r3_r5_ASR_11),
    kInstruction_mov_cs_r3_r5_ASR_11,
  },
  {
    ARRAY_SIZE(kInstruction_mov_gt_r7_r0_ASR_19),
    kInstruction_mov_gt_r7_r0_ASR_19,
  },
};

#endif  // VIXL_ASSEMBLER_COND_RD_OPERAND_RN_SHIFT_AMOUNT_1TO32_IN_IT_BLOCK_MOV_T32_H_
